@@ -41,7 +41,6 @@ class StatsQSOsPerMonthBarChartWidget : public StatsGeneralChartWidget
     Q_OBJECT
 public:
     StatsQSOsPerMonthBarChartWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
-    StatsQSOsPerMonthBarChartWidget();
     ~StatsQSOsPerMonthBarChartWidget();
     void prepareChart(const int _log=-1);
 
@@ -53,7 +52,7 @@ private:
     void createUI();
     DataProxy_SQLite *dataProxy;
 
-    QChart *chart;
+    //QChart *chart;
     QChartView *chartView;
 
 };
