@@ -67,7 +67,7 @@ public:
     int getIdFromBandName(const QString& _bandName);
     int getSubModeIdFromSubMode(const QString &_subModeName);
     int getModeIdFromSubModeId(const int _sm);
-
+    void setCallValidation(const bool _v);
     QStringList getFields();
     QStringList getBands();
     QStringList getModes();
@@ -186,10 +186,11 @@ public:
     QList<int> getQSOsListeQSLNotSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justQueued=true);
 
     QList<int> getQSOsListClubLogToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true, int _logN = -1);
-    QList<int> getQSOsListEQSLToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
-    QList<int> getQSOsListQRZCOMToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true);
-    QList<int> getQSOsListToBeExported(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate);
-    QStringList getGridsToBeSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true, int _logN = -1);
+    QList<int> getQSOsListEQSLToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true, int _logN = -1);
+    QList<int> getQSOsListQRZCOMToSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, bool _justModified=true, int _logN = -1);
+    QList<int> getQSOsListToBeExported(const QString &_stationCallsign, const QString &_grid, const QDate &_startDate, const QDate &_endDate, int _logN = -1);
+    QList<int> getQSOsAll();
+    QStringList getGridsToBeSent(const QString &_stationCallsign, const QDate &_startDate, const QDate &_endDate, const ExportMode _em, bool _justModified=true, int _logN = -1);
 
 
     int getContinentIdFromContinentShortName(const QString &_n);
@@ -247,6 +248,7 @@ public:
 
     int getQSOsInBand(const QString &_band, const int _log);
     int getQSOsInMode(const QString &_mode, const int _log);
+    int getDXCCInBand(const int _bandid, const bool _confirmed, const int _log);
 
     QList<QList<int>> getTop10QSOPerDXCC(const int _log);
 
@@ -273,8 +275,8 @@ public:
     bool addSatellite(const QString &_arrlId, const QString &_name, const QString &_downLink, const QString &_upLink, const QString &_mode, int id = -1);
     int getDBSatId(const QString &_arrlId);
     QStringList getSatellitesList();
-    QString getSatelliteUplink(const QString &_sat);
-    QString getSatelliteDownlink(const QString &_sat);
+    QString getSatelliteUplink(const QString &_sat, int _pair=0);
+    QString getSatelliteDownlink(const QString &_sat, int _pair=0);
     QString getSatelliteMode(const QString &_sat);
     QString getSatelliteFullUplink(const QString &_sat);
     QString getSatelliteFullDownlink(const QString &_sat);
@@ -330,7 +332,7 @@ private:
     bool dbCreated;
     DataBase *db;
     QStringList sortBandIdBottonUp(const QStringList _qs);
-    double getFreqFromRange(QString _fr); //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
+    double getFreqFromRange(QString _fr, int _pair = 0); //May even receive: 145.900-146.00 and should return the mid in the range (145.950)
     QStringList getColumnNamesFromTable(const QString &_tableName);
 
     int getPrefixId(const QString &_qrz);
