@@ -50,12 +50,16 @@ class DXClusterWidget : public QWidget
     ~DXClusterWidget();
     void setColors (const QString &_newOne, const QString &_needed, const QString &_worked, const QString &_confirmed, const QString &_default);
     void setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy );
-    void setDXClusterServer(const QString &clusterToConnect, const int portToConnect);
+    //void setDXClusterServer(const QString &clusterToConnect, const int portToConnect);
     void setCurrentLog(const int _log);
     bool isConnected();
     void setMyQRZ(const QString &_qrz);
     void setDXMarathon (const bool _enable);
     void setSaveSpots (const bool _enable);
+    void loadSettings();
+    void setDXClusterServer(const QString &clusterToConnect, const int portToConnect);
+
+    void rightButtonFromLogMenu(const QStringList _ql);
     //void sendSpotToCluster(const QString &_dx, const QString &_freq);
 
 private slots:
@@ -70,6 +74,8 @@ private slots:
     void slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item );
     void slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item);
     void slotClusterDXClusterWidgetItemSelected();
+    void slotRighButton (const QPoint& pos);
+    void slotCheckQRZCom();
 
 signals:
     void dxspotclicked(const QStringList &_qs); // DXSpotCall, DX-Freq, doubleClicked
@@ -80,7 +86,7 @@ private:
 
     //void TESTADDSPOT(); // Just a test spot
 
-
+    void createActions();
     void connectToDXCluster();
     QStringList readItem(QListWidgetItem * item);
     bool checkIfNeedsToBePrinted(const QString &_DXEntity, const int _band, const int _mode);
@@ -118,6 +124,8 @@ private:
     QFile *saveSpotsFile;
     bool saveSpots; // write/save the spots to a file
 
+    QAction *checkQRZCOMFromLogAct;
+
  };
 
 class dxClusterSpotItem : public QListWidgetItem {
