@@ -43,7 +43,7 @@ public:
     explicit eLogClubLog();
     ~eLogClubLog();
 
-    void setCredentials(const QString &_email, const QString &_pass, const QString &_defaultStationCallsign);
+    void setDefaultCallsign(const QString &_defaultStationCallsign);
     int sendQSO(QStringList _qso);
 
     int deleteQSO(QStringList _qso);
@@ -51,7 +51,7 @@ public:
     int modifyQSO (QStringList _oldQSO, QStringList _newQSO);
 
     void sendLogFile(const QString &_file, QList<int> _qso, bool _overwrite);
-
+    void loadSettings();
 
 private:
     QString getClubLogAdif(const QStringList _q);
@@ -60,7 +60,7 @@ private:
     QString prepareToTranslate(const QString &_m);       //  Get the message and put it in a tr to be able to translate it
 
 
-    QString email, pass, api, stationCallsign;
+    QString email, pass, appPass, api, stationCallsign;
 
     QNetworkAccessManager *manager;
     QNetworkReply* reply;
