@@ -31,21 +31,20 @@ This class implements the Satellite TAB of the MainWindow
 MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
     QWidget(parent)
 {
-       //qDebug() << "MainWindowSatTab::MainWindowSatTab"   << QT_ENDL;
+       //qDebug() << "MainWindowSatTab::MainWindowSatTab"  ;
     satNameComboBox = new QComboBox;
     satNameLineEdit = new QLineEdit;
     satModeLineEdit = new QLineEdit;
-    satDXLocatorLineEdit = new QLineEdit;
+
     satOtherLabel = new QLabel;
     satBandTXComboBox = new QComboBox;
     satBandRXComboBox = new QComboBox;
-    txFreqSpinBox = new QDoubleSpinBox;
-    rxFreqSpinBox = new QDoubleSpinBox;
+    //txFreqSpinBox = new QDoubleSpinBox;
+    //rxFreqSpinBox = new QDoubleSpinBox;
 
     keepThisDataForNextQSOQcheckbox = new QCheckBox;
 
     dataProxy = dp;
-    locator = new Locator;
     util = new Utilities(Q_FUNC_INFO);
 
     createUI();
@@ -56,6 +55,7 @@ MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
     modifying = false;
     //txBandsBeingChanged = false;
     updatingBands = false;
+    updatingSat = false;
     satNameLineEdit->setEnabled(false);
     satOtherLabel->setEnabled(false);
     palRed.setColor(QPalette::Text, Qt::red);
@@ -63,11 +63,10 @@ MainWindowSatTab::MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent) :
     palWhite.setColor(QPalette::Text, Qt::white);
 
     setDefaultBands(); //TODO: Check how the bands are included not to create an inconsistence with the selected (in the setup) bands
-       //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"   << QT_ENDL;
+       //qDebug() << "MainWindowSatTab::MainWindowSatTab - END"  ;
 }
 
 MainWindowSatTab::~MainWindowSatTab(){
-    delete(locator);
     delete(util);
     delete(dataProxy);
 }
@@ -76,18 +75,16 @@ void MainWindowSatTab::createUI()
 {
     connect(satNameLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSatNameTextChanged() ) );
     connect(satModeLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSatModeTextChanged() ) );
-    connect(satDXLocatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSatDXLocTextChanged() ) );
+    //connect(satDXLocatorLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSatDXLocTextChanged() ) );
     connect(satNameLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
     connect(satModeLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
-    connect(satDXLocatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
+    //connect(satDXLocatorLineEdit, SIGNAL(returnPressed()), this, SLOT(slotReturnPressed()) );
 
     connect(satNameComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatNameComboBoxChanged() ) ) ;
 
     connect(satBandRXComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatBandRXComboBoxChanged()) ) ;
     connect(satBandTXComboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(slotSatBandTXComboBoxChanged()) ) ;
 
-    connect(txFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqTXChanged(double)) ) ;
-    connect(rxFreqSpinBox, SIGNAL(valueChanged(double)), this, SLOT(slotSatFreqRXChanged(double)) ) ;
     connect (keepThisDataForNextQSOQcheckbox, SIGNAL(clicked()), this, SLOT(slotSatKeepThisDataClicked()) );
 
     QLabel *keepLabel = new QLabel();
@@ -106,7 +103,6 @@ void MainWindowSatTab::createUI()
     satNameComboBox->setToolTip(tr("Select the satellite you are using."));
     satBandTXComboBox->setToolTip(tr("UpLink band."));
     satBandRXComboBox->setToolTip(tr("DownLink band."));
-    satDXLocatorLineEdit->setToolTip(tr("Locator of the DX station. This box is synchronized with the Locator box in the QSO tab."));
 
     QLabel *upLinkLabel = new QLabel();
     upLinkLabel->setText(tr("UpLink"));
@@ -124,21 +120,17 @@ void MainWindowSatTab::createUI()
     satModeLabel->setText(tr("Mode"));
     satModeLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
 
-    QLabel *satDXLocLabel = new QLabel();
-    satDXLocLabel->setText(tr("DX Locator"));
-    satDXLocLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
-
     //QLabel *satOtherLabel = new QLabel();
     satOtherLabel->setText(tr("Other"));
     satOtherLabel->setAlignment(Qt::AlignVCenter| Qt::AlignRight);
 
-    txFreqSpinBox->setDecimals(3);
-    txFreqSpinBox->setMaximum(99999);
-    txFreqSpinBox->setSuffix(" " + tr("MHz"));
+    //txFreqSpinBox->setDecimals(3);
+    //txFreqSpinBox->setMaximum(99999);
+    //txFreqSpinBox->setSuffix(" " + tr("MHz"));
 
-    rxFreqSpinBox->setDecimals(3);
-    rxFreqSpinBox->setMaximum(99999);
-    rxFreqSpinBox->setSuffix(" " + tr("MHz"));
+    //rxFreqSpinBox->setDecimals(3);
+    //rxFreqSpinBox->setMaximum(99999);
+    //rxFreqSpinBox->setSuffix(" " + tr("MHz"));
 
     QHBoxLayout *keepLayout = new QHBoxLayout;
     keepLayout->addWidget(keepLabel);
@@ -147,8 +139,6 @@ void MainWindowSatTab::createUI()
     QHBoxLayout *lastlineLayout = new QHBoxLayout;
     //lastlineLayout->addWidget(satModeLabel);
     lastlineLayout->addWidget(satModeLineEdit);
-    lastlineLayout->addWidget(satDXLocLabel);
-    lastlineLayout->addWidget(satDXLocatorLineEdit);
 
     QGridLayout *tabLayout = new QGridLayout;
 
@@ -165,8 +155,8 @@ void MainWindowSatTab::createUI()
     //tabLayout->addWidget(satModeLineEdit,3,1,1,-1);
 
     tabLayout->addWidget(satNameLineEdit,0,2);
-    tabLayout->addWidget(txFreqSpinBox,1,2);
-    tabLayout->addWidget(rxFreqSpinBox,2,2);
+    //tabLayout->addWidget(txFreqSpinBox,1,2);
+    //tabLayout->addWidget(rxFreqSpinBox,2,2);
 
     tabLayout->addLayout(keepLayout,3,2);
     tabLayout->setSizeConstraint(QLayout::SetFixedSize);
@@ -175,14 +165,15 @@ void MainWindowSatTab::createUI()
 
 void MainWindowSatTab::slotSatNameComboBoxChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << satNameComboBox->currentText() << QT_ENDL;
+   //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << satNameComboBox->currentText();
     if (modifying || (satNameComboBox->currentText().length()<4))
     {
         return;
     }
+    updatingSat = true;
 
     int i = satNameComboBox->currentIndex();
-   //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << QString::number(i) << QT_ENDL;
+   //qDebug() << "MainWindowSatTab::slotSatNameComboBoxChanged: " << QString::number(i);
     //QString _pm = (((satNameComboBox->currentText()).split(' ')).at(0)).simplified();
 
     satNameLineEdit->clear();
@@ -209,12 +200,13 @@ void MainWindowSatTab::slotSatNameComboBoxChanged()
         setBandsOfSat(satNameComboBox->currentText());
        //dataProxy->getSatelliteMode(satNameComboBox->currentText())
         autofillSatMode();
-    }  
+    }
+    updatingSat = false;
 }
 
 void MainWindowSatTab::slotSatNameTextChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatNameTextChanged: " << satNameLineEdit->text() << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::slotSatNameTextChanged: " << satNameLineEdit->text();
     int cursor = satNameLineEdit->cursorPosition ();
     satNameLineEdit->setText((util->getClearSQLi (satNameLineEdit->text())).toUpper());
 
@@ -237,7 +229,7 @@ void MainWindowSatTab::slotSatNameTextChanged()
 
 void MainWindowSatTab::slotSatModeTextChanged()
 {
-    //qDebug() << "MainWindowSatTab::slotSatModeTextChanged: " << satModeLineEdit->text() << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::slotSatModeTextChanged: " << satModeLineEdit->text();
 /*
     satModeLineEdit->setText((satModeLineEdit->text()).toUpper());
 
@@ -252,49 +244,6 @@ void MainWindowSatTab::slotSatModeTextChanged()
 */
 }
 
-void MainWindowSatTab::setLocator(const QString &_t)
-{
-    //qDebug() << "MainWindowSatTab::setLocator: " << _t << QT_ENDL;
-    satDXLocatorLineEdit->setText(_t.toUpper());
-    //qDebug() << "MainWindowSatTab::setLocator - END: "  << QT_ENDL;
-}
-
-void MainWindowSatTab::slotSatDXLocTextChanged()
-{
-    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged: " << satDXLocatorLineEdit->text() << QT_ENDL;
-    int cursorP = satDXLocatorLineEdit->cursorPosition();
-
-    satDXLocatorLineEdit->setText((util->getClearSQLi(satDXLocatorLineEdit->text())).toUpper());
-
-    if ( locator->isValidLocator(satDXLocatorLineEdit->text()) )
-    {
-        if (getDarkMode())
-        {
-            satDXLocatorLineEdit->setPalette(palWhite);
-        }
-        else
-        {
-            satDXLocatorLineEdit->setPalette(palBlack);
-        }
-
-        satDXLocatorLineEdit->setToolTip(tr("Locator of the DX station. This box is synchronized with the Locator box in the QSO tab."));
-
-        //if (!modifying)
-        //{
-        //    emit dxLocatorChanged((satDXLocatorLineEdit->text()).toUpper());
-        //}
-    }
-    else
-    {
-        satDXLocatorLineEdit->setPalette(palRed);
-        satDXLocatorLineEdit->setToolTip(tr("Locator of the DX station. Format should be Maidenhead like IN70AA up to 10 characters."));
-    }
-    satDXLocatorLineEdit->setCursorPosition(cursorP);
-    emit dxLocatorChanged(satDXLocatorLineEdit->text());
-
-    //qDebug() << "MainWindowSatTab::slotSatDXLocTextChanged - END"  << QT_ENDL;
-}
-
 QString MainWindowSatTab::getSatName()
 {
     // Sat name must follow the format CC-NN to make it compatible with LOTW
@@ -306,13 +255,13 @@ QString MainWindowSatTab::getSatName()
     //TODO: Check that the format is OK
     return satName;
  */
-    //qDebug() << "MainWindowSatTab::getSatName:" << satNameComboBox->currentText() << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::getSatName:" << satNameComboBox->currentText();
     QString _pm = QString();
     QString satName = QString();
 
     _pm = (((satNameComboBox->currentText()).split(' ')).at(0)).simplified();
 
-       //qDebug() << "MainWindowSatTab::satNameComboBox: " << _pm << QT_ENDL;
+       //qDebug() << "MainWindowSatTab::satNameComboBox: " << _pm;
     if (satNameComboBox->currentIndex() == 0)
     {
         return QString();
@@ -338,13 +287,14 @@ QString MainWindowSatTab::getSatName()
 void MainWindowSatTab::setNoSat()
 {
    satNameComboBox->setCurrentIndex(0);
+   setSatMode("-CLEAR-");
    keepThisDataForNextQSOQcheckbox->setChecked(false);
 }
 
 void MainWindowSatTab::setSatName(const QString &_t)
 {
      //TODO: Check that the format is OK
-    //qDebug() << "MainWindowSatTab::setSatName: " << _t << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::setSatName: " << _t;
     //satNameLineEdit->setText(_t);
     if (_t =="")
     {
@@ -363,13 +313,13 @@ void MainWindowSatTab::setSatName(const QString &_t)
 
 QString MainWindowSatTab::getSatMode()
 {
-    //qDebug() << "MainWindowSatTab::getSatMode: " << satModeLineEdit->text() << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": " << satModeLineEdit->text();
     return satModeLineEdit->text();
 }
 
 void MainWindowSatTab::setSatMode(const QString &_t)
 {
-    //qDebug() << "MainWindowSatTab::setSatMode: " << _t ;
+    //qDebug() << Q_FUNC_INFO << ": " << _t ;
     if (_t == "-CLEAR-")
     {
         satModeLineEdit->clear();
@@ -382,30 +332,28 @@ void MainWindowSatTab::setSatMode(const QString &_t)
 
 bool MainWindowSatTab::getRepeatThis()
 {
-    //qDebug() << "MainWindowSatTab::getRepeatThis: "  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     return keepThisDataForNextQSOQcheckbox->isChecked();
 }
 
 void MainWindowSatTab::setRepeatThis(const bool _t)
 {
-    //qDebug() << "MainWindowSatTab::setRepeatThis: "  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     keepThisDataForNextQSOQcheckbox->setChecked(_t);
 }
 
 void MainWindowSatTab::clear(bool _full)
 {
-    //qDebug() << "MainWindowSatTab::clear"  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     modifying = false;
     if ((keepThisDataForNextQSOQcheckbox->isChecked()) || (!_full))
     {
-        satDXLocatorLineEdit->clear();
     }
     else
     {
         satModeLineEdit->clear();
         satNameComboBox->setCurrentIndex(0);
         satNameLineEdit->clear();
-        satDXLocatorLineEdit->clear();
     }
     if (_full)
     {
@@ -415,14 +363,14 @@ void MainWindowSatTab::clear(bool _full)
 
 void MainWindowSatTab::refreshData()
 {
-    //qDebug() << "MainWindowSatTab::refreshData"  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     populateSatComboBox();
     //autofillSatMode();
 }
 
 void MainWindowSatTab::populateSatComboBox()
 {
-    //qDebug() << "MainWindowSatTab::populateSatComboBox: " << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
 
     QString nosat = tr("Not Sat QSO");
     QString othersat = tr("Other - Sat not in the list");
@@ -445,11 +393,11 @@ void MainWindowSatTab::populateSatComboBox()
 
 void MainWindowSatTab::setSatelliteCombo(const QString &_p)
 {
-    //qDebug() << "MainWindowsatTab::setSatelliteCombo: " << _p << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start: " << _p ;
     QString aux = QString();
     int indexC = getSatIndex(_p);
     //int indexC = satNameComboBox->findText(_p, Qt::MatchContains);
-       //qDebug() << "MainWindowsatTab::setSatelliteCombo: N=" << QString::number(indexC) << QT_ENDL;
+       //qDebug() << "MainWindowsatTab::setSatelliteCombo: N=" << QString::number(indexC);
     if (indexC>0)
     {
         satNameComboBox->setCurrentIndex(indexC);
@@ -480,25 +428,25 @@ void MainWindowSatTab::setSatelliteCombo(const QString &_p)
 
 void MainWindowSatTab::setOtherSatName(const QString &_t)
 {
-    //qDebug() << "MainWindowsatTab::setOtherSatName: " << _t << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start: " << _t ;
     satNameLineEdit->setText(_t);
 }
 
 QString MainWindowSatTab::getOtherSatName()
 {
-    //qDebug() << "MainWindowSatTab::getOtherSatName"  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     return QString();
 }
 
 int MainWindowSatTab::getSatIndex(const QString &_p)
 {
-    //qDebug() << "MainWindowSatTab::getSatIndex: " << QString::number(satNameComboBox->findText(_p, Qt::MatchContains))  << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::getSatIndex: " << QString::number(satNameComboBox->findText(_p, Qt::MatchContains)) ;
     return satNameComboBox->findText(_p, Qt::MatchContains);
 }
 
 void MainWindowSatTab::addBands(QStringList _bands)
 {
-    //qDebug() << "MainWindowSatTab::addBands: " << QString::number(_bands.length()) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start: "  << QString::number(_bands.length());
     updatingBands = true;
     QString _txBand = satBandTXComboBox->currentText();
     QString _rxBand = satBandRXComboBox->currentText();
@@ -511,12 +459,12 @@ void MainWindowSatTab::addBands(QStringList _bands)
     satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(_rxBand, Qt::MatchCaseSensitive));
     //txBandsBeingChanged = false;
     updatingBands = false;
-    //qDebug() << "MainWindowSatTab::addBands - END"  << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::addBands - END" ;
 }
 
 void MainWindowSatTab::setDefaultBands()
 {//Defines the default bands for SAT communications: 10m/2m/70cm/23CM only if they exist in the selected bands
-    //qDebug() << "MainWindowsatTab::setDefaultBands: " << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     QStringList _b;
     _b.clear();
 
@@ -527,156 +475,94 @@ void MainWindowSatTab::setDefaultBands()
 
 void MainWindowSatTab::slotSatBandRXComboBoxChanged()
 {
-    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged" << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
     if (updatingBands || modifying)
     {
         return;
     }
-    bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(rxFreqSpinBox->value()));
+
+    bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(freqRX));
     if(!freqInBand)
     { // If the freq does not belong to the current band, we need to update the band
-        rxFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandRXComboBox->currentText()));
-    }
-    //qDebug() << "MainWindowsatTab::slotSatBandRXComboBoxChanged-END" << QT_ENDL;
-    autofillSatMode();
-}
-
-void MainWindowSatTab::slotSatFreqRXChanged(const double _f)
-{
-    //qDebug() << Q_FUNC_INFO << ": spingBox: " << QString::number(rxFreqSpinBox->value()) << QT_ENDL;
-    //qDebug() << Q_FUNC_INFO << ": f: " << QString::number(_f) << QT_ENDL;
-    //qDebug() << Q_FUNC_INFO << ": freqRx:" << QString::number(freqRX) << QT_ENDL;
-    if (util->isSameFreq (freqRX, _f))
-    {
-        return;
-    }
-    freqRX = _f;
-
-    if (getDarkMode())
-    {
-        rxFreqSpinBox->setPalette(palWhite);
-    }
-    else
-    {
-        rxFreqSpinBox->setPalette(palBlack);
+       //qDebug() << Q_FUNC_INFO << " changing to: Band: " << satBandTXComboBox->currentText() ;
+        //qDebug() << Q_FUNC_INFO << " changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText())) ;
+        setNoSat ();
+        updateRXFreq(dataProxy->getLowLimitBandFromBandName(satBandRXComboBox->currentText()));
     }
 
-    if (modifying)
-    {
-        return;
-    }
-
-    int bandId = dataProxy->getBandIdFromFreq(rxFreqSpinBox->value());
-    if (bandId<1)
-    { //This prevent that a non-hamradio frequency is used on TX
-        //qDebug() << Q_FUNC_INFO << ":  Not in band, exiting... " << QT_ENDL;
-        rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz.\nFrequency is not in a hamradio band!"));
-        rxFreqSpinBox->setPalette(palRed);
-    }
-    else
-    {
-        rxFreqSpinBox->setToolTip(tr("RX Frequency in MHz."));
-        bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(rxFreqSpinBox->value()));
-        if(!freqInBand)
-        { // If the freq does not belong to the current band, we need to update the band
-            satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(dataProxy->getBandNameFromFreq(rxFreqSpinBox->value()), Qt::MatchCaseSensitive));
-        }
-    }
-    emit satRxFreqChanged(rxFreqSpinBox->value());
     //qDebug() << Q_FUNC_INFO << " - END";
+    autofillSatMode();
 }
 
 void MainWindowSatTab::slotSatBandTXComboBoxChanged()
 {
-    //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged: -" << satBandTXComboBox->currentText()  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - " << satBandTXComboBox->currentText();
     if (updatingBands || modifying || (satBandTXComboBox->currentText().length()<2))
     {
         return;
     }
-    bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
+    //qDebug() << Q_FUNC_INFO << " - Freq: " << QString::number(freqTX);
+    QString tmpBand = satBandTXComboBox->currentText();
+    bool freqInBand = dataProxy->isThisFreqInBand(tmpBand, QString::number(freqTX));
     if(!freqInBand)
     { // If the freq does not belong to the current band, we need to update the band
-       //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: Band: " << satBandTXComboBox->currentText()  << QT_ENDL;
-        //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()))  << QT_ENDL;
-        txFreqSpinBox->setValue(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
-        //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
-    }
-   //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged-END" << QT_ENDL;
-    autofillSatMode();
-}
+       //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: Band: " << satBandTXComboBox->currentText() ;
+        //qDebug() << "MainWindowsatTab::slotSatBandTXComboBoxChanged changing to: " << QString::number(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText())) ;
+        QString tmpFreq = dataProxy->getFreqFromBandId(dataProxy->getIdFromBandName(satBandTXComboBox->currentText()));
+        //qDebug() << ": Normal" << dataProxy->getSatelliteUplink(getSatName());
+        //qDebug() << ": Normal1" << dataProxy->getSatelliteUplink(getSatName(), 1);
+        //qDebug() << ": Normal2" << dataProxy->getSatelliteUplink(getSatName(), 2);
+        //qDebug() << ": Full" << dataProxy->getSatelliteFullUplink(getSatName());
 
-void MainWindowSatTab::slotSatFreqTXChanged(const double _f)
-{
-    //qDebug() << Q_FUNC_INFO << QString::number(txFreqSpinBox->value());
-    // user changes TX Freq
-    // If band is real and band is configured, bandcombo is selected
-    // If band is real and not configured, we launch the band config and select the band.
-    // if band is real emit the band
-    if (util->isSameFreq (freqTX, _f))
-    {
-        //qDebug() << Q_FUNC_INFO << " - END-1";
-        return;
-    }
-    freqTX = _f;
-
-    if (getDarkMode())
-    {
-        txFreqSpinBox->setPalette(palWhite);
-    }
-    else
-    {
-        txFreqSpinBox->setPalette(palBlack);
-    }
-
-    if (modifying)
-    {
-        //qDebug() << Q_FUNC_INFO << " - END-2";
-        return;
-    }
-
-    int bandId = dataProxy->getBandIdFromFreq(txFreqSpinBox->value());
-    if (bandId<1)
-    { //This prevent that a non-hamradio frequency is used on TX
-          //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Not in band, exiting... " << QT_ENDL;
-        txFreqSpinBox->setToolTip(tr("TX Frequency in MHz.\nFrequency is not in a hamradio band!"));
-        txFreqSpinBox->setPalette(palRed);
-    }
-    else
-    {
-        txFreqSpinBox->setToolTip(tr("TX Frequency in MHz."));
-        bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(txFreqSpinBox->value()));
-        if(!freqInBand)
-        { // If the freq does not belong to the current band, we need to update the band
-            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: If the freq does not belong to the current band, we need to update the band" << QT_ENDL;
-            //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: We define UoLink to: " << dataProxy->getBandNameFromFreq(txFreqSpinBox->value()) << QT_ENDL;
-            satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(dataProxy->getBandNameFromFreq(txFreqSpinBox->value()), Qt::MatchCaseSensitive));
-            //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
+        double upLink = tmpFreq.toDouble();
+        double downLink;
+        if (dataProxy->isThisFreqInBand(tmpBand,dataProxy->getSatelliteUplink(getSatName(),1)) )
+        {
+            upLink = (dataProxy->getSatelliteUplink(getSatName(),1)).toDouble();
+            downLink = (dataProxy->getSatelliteDownlink(getSatName(),1)).toDouble();
+            updateRXFreq(downLink);
         }
-    //autofillSatMode();
+        else if (dataProxy->isThisFreqInBand(tmpBand,dataProxy->getSatelliteUplink(getSatName(),0)) )
+        {
+            upLink = (dataProxy->getSatelliteUplink(getSatName(),0)).toDouble();
+            downLink = (dataProxy->getSatelliteDownlink(getSatName(),1)).toDouble();
+            updateRXFreq(downLink);
+        }
+        else
+        {
+            //qDebug() << Q_FUNC_INFO << " - Selected satelite does not work in the selected band. NO sat should be selected";
+            setNoSat ();
+        }
+
+        updateTXFreq(upLink);
     }
 
-    //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Emitting: " << QString::number(txFreqSpinBox->value()) << QT_ENDL;
-    emit satTxFreqChanged(txFreqSpinBox->value());
-    //qDebug() << Q_FUNC_INFO << " - END";
+    autofillSatMode();
+    //qDebug() << Q_FUNC_INFO << " - END" ;
 }
 
 void MainWindowSatTab::setUpLink(const QString &_t)
 {
-    //qDebug() << Q_FUNC_INFO << "Start: " << _t ;
+   //qDebug() << Q_FUNC_INFO << "Start: " << _t ;
     if (satBandTXComboBox->currentText () == _t)
     {
         //qDebug() << Q_FUNC_INFO << "END-1";
         return;
     }
     int index = satBandTXComboBox->findText(_t, Qt::MatchCaseSensitive);
-    //qDebug() << "MainWindowsatTab::setUpLink: new index: " << QString::number(index) << QT_ENDL;
-    //qDebug() << "MainWindowsatTab::setUpLink: current index: " << QString::number(satBandTXComboBox->currentIndex()) << QT_ENDL;
-    int indexRX;
+    //qDebug() << "MainWindowsatTab::setUpLink: new index: " << QString::number(index);
+    //qDebug() << "MainWindowsatTab::setUpLink: current index: " << QString::number(satBandTXComboBox->currentIndex());
+    //int indexRX;
     if (index>=0)
     {
         satBandTXComboBox->setCurrentIndex(index);
-         if ( dataProxy->getIdFromBandName("2M") ==  dataProxy->getIdFromBandName(_t) )
-         {
+    }
+    /*
+    if (index>=0)
+    {
+        satBandTXComboBox->setCurrentIndex(index);
+        if ( dataProxy->getIdFromBandName("2M") ==  dataProxy->getIdFromBandName(_t) )
+        {
              //qDebug() << satNameComboBox->currentText() ;
              if (satNameComboBox->findText("AO-7 - AMSAT-OSCAT 7", Qt::MatchCaseSensitive))
              {
@@ -686,7 +572,6 @@ void MainWindowSatTab::setUpLink(const QString &_t)
              {
                  indexRX = satBandRXComboBox->findText("70CM", Qt::MatchCaseSensitive);
              }
-
              satBandRXComboBox->setCurrentIndex(indexRX);
          }
          else if ( dataProxy->getIdFromBandName("70CM") ==  dataProxy->getIdFromBandName(_t) )
@@ -695,49 +580,137 @@ void MainWindowSatTab::setUpLink(const QString &_t)
              satBandRXComboBox->setCurrentIndex(indexRX);
          }
      }
+    */
     //qDebug() << Q_FUNC_INFO << "END";
 }
 
 void MainWindowSatTab::setUpLinkFreq(const double _t)
 {
     //qDebug() << Q_FUNC_INFO << ": " << QString::number(_t);
-    if (util->isSameFreq (freqTX, _t))
+    if (!updatingSat)
     {
-        //qDebug() << Q_FUNC_INFO << "END-1";
-        return;
+        setNoSat ();
     }
-
-    txFreqSpinBox->setValue(_t);
+    updateTXFreq(_t);
     setUpLink(dataProxy->getBandNameFromFreq(_t));
-
-   //qDebug() << Q_FUNC_INFO << "END";
+    //qDebug() << Q_FUNC_INFO << "END";
 }
 
 double MainWindowSatTab::getRXFreq()
 {
-    //qDebug() << "MainWindowsatTab::getRXFreq " << QT_ENDL;
-    return rxFreqSpinBox->value();
+    //qDebug() << Q_FUNC_INFO << " - Start" ;
+    return freqRX;
 }
 
+//double MainWindowSatTab::getTXFreq()
+//{
+//    return freqTX;
+//}
+
 void MainWindowSatTab::setDownLinkFreq(const double _t)
 {
-    //qDebug() << "MainWindowsatTab::setDownLinkFreq: " << QString::number(_t) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_t);
     if (util->isSameFreq (freqRX, _t))
     {
-        //qDebug() << Q_FUNC_INFO << " - I same freq";
+        //qDebug() << Q_FUNC_INFO << " - Is same freq";
         return;
     }
 
-    rxFreqSpinBox->setValue(_t);
-    QString downLinkBand = dataProxy->getBandNameFromFreq(_t);
+    updateRXFreq(_t);
+    QString downLinkBand = dataProxy->getBandNameFromFreq(freqRX);
 
     int index = satBandRXComboBox->findText(downLinkBand, Qt::MatchCaseSensitive);
+    //qDebug() << Q_FUNC_INFO << ": " << downLinkBand;
     if (index>=0)
     {
         satBandRXComboBox->setCurrentIndex(index);
     }
+   //qDebug() << Q_FUNC_INFO << " - END";
+}
 
-    //qDebug() << "MainWindowsatTab::setDownLinkFreq END" << QT_ENDL;
+void MainWindowSatTab::updateRXFreq(const double _f)
+{
+    //qDebug() << Q_FUNC_INFO << QString::number(_f);
+
+    if (util->isSameFreq (freqRX, _f))
+    {
+        //qDebug() << Q_FUNC_INFO << " - END-1";
+        return;
+    }
+    freqRX = _f;
+
+    if (modifying)
+    {
+        //qDebug() << Q_FUNC_INFO << " - END-2";
+        return;
+    }
+
+
+    int bandId = dataProxy->getBandIdFromFreq(freqRX);
+    if (bandId>=1)
+    { //This prevent that a non-hamradio frequency is used on TX
+        //qDebug() << Q_FUNC_INFO << " - Freq not in ham band";
+        bool freqInBand = dataProxy->isThisFreqInBand(satBandRXComboBox->currentText(), QString::number(freqRX));
+        if(!freqInBand)
+        { // If the freq does not belong to the current band, we need to update the band
+            //qDebug() << Q_FUNC_INFO << " - Freq in current band";
+            QString aux;
+            aux = dataProxy->getBandNameFromFreq(freqRX);
+            if (satBandRXComboBox->findText(aux, Qt::MatchCaseSensitive)<0)
+            {
+                addNewBand(aux);
+            }
+            //addNewBand(const QString &_p)
+            satBandRXComboBox->setCurrentIndex(satBandRXComboBox->findText(aux, Qt::MatchCaseSensitive));
+        }
+    }
+    emit satRxFreqChanged(freqRX);
+    //qDebug() << Q_FUNC_INFO << " - END";
+}
+
+void MainWindowSatTab::updateTXFreq(const double _f)
+{
+    //qDebug() << Q_FUNC_INFO << QString::number(txFreqSpinBox->value());
+        // user changes TX Freq
+        // If band is real and band is configured, bandcombo is selected
+        // If band is real and not configured, we launch the band config and select the band.
+        // if band is real emit the band
+        if (util->isSameFreq (freqTX, _f))
+        {
+            //qDebug() << Q_FUNC_INFO << " - END-1";
+            return;
+        }
+        freqTX = _f;
+
+        if (modifying)
+        {
+            //qDebug() << Q_FUNC_INFO << " - END-2";
+            return;
+        }
+
+        int bandId = dataProxy->getBandIdFromFreq(freqTX);
+        if (bandId>=1)
+        { //This prevent that a non-hamradio frequency is used on TX
+            bool freqInBand = dataProxy->isThisFreqInBand(satBandTXComboBox->currentText(), QString::number(freqTX));
+            if(!freqInBand)
+            { // If the freq does not belong to the current band, we need to update the band
+                //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: If the freq does not belong to the current band, we need to update the band";
+                //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: We define UpLink to: " << dataProxy->getBandNameFromFreq(txFreqSpinBox->value());
+                QString aux = dataProxy->getBandNameFromFreq(freqTX);
+                //qDebug() << Q_FUNC_INFO << QString("FreqTx = %1 / Band = %2").arg(freqTX).arg(aux);
+                if (satBandTXComboBox->findText(aux, Qt::MatchCaseSensitive)<0)
+                {
+                    addNewBand(aux);
+                }
+                satBandTXComboBox->setCurrentIndex(satBandTXComboBox->findText(aux, Qt::MatchCaseSensitive));
+                //setUpLinkFreq(dataProxy->getLowLimitBandFromBandName(satBandTXComboBox->currentText()));
+            }
+        //autofillSatMode();
+        }
+
+        //qDebug() << "MainWindowsatTab::slotSatFreqTXChanged: Emitting: " << QString::number(txFreqSpinBox->value());
+        emit satTxFreqChanged(freqTX);
+        //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void MainWindowSatTab::setBandsOfSat(const QString &_p)
@@ -745,7 +718,7 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     // Until the data is in the DB, this function tries to solve data of active sats from: http://www.amsat.org/status/
     // This functio:
     //  - identifies the freqs & bands that the sat is using
-    //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - Short: " << _p.section(' ', 0, 0) << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": " << _p << " - Short: " << _p.section(' ', 0, 0);
     //"AO-7 - AMSAT-OSCAT 7"
     //2M/10M << 2M/70CM
     if (modifying)
@@ -756,8 +729,8 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     double upLink = (dataProxy->getSatelliteUplink(_p.section(' ', 0, 0))).toDouble();
     double downLink = (dataProxy->getSatelliteDownlink(_p.section(' ', 0, 0))).toDouble();
 
-    //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: " << QString::number(upLink)<< QT_ENDL;
-    //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: " << QString::number(downLink)<< QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": upLink: " << QString::number(upLink)<< QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ":  downLink: " << QString::number(downLink)<< QT_ENDL;
 
     if (upLink>0)
     {
@@ -768,8 +741,7 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     else
     {
         //qDebug() << "MainWindowSatTab::setBandsOfSat upLink: setting to ZERO (should be = RX) " <<  QT_ENDL;
-        txFreqSpinBox->setValue(0);
-        //satBandTXComboBox->setCurrentIndex(0);
+        updateTXFreq(0.0);
     }
 
     if (downLink>0)
@@ -781,27 +753,29 @@ void MainWindowSatTab::setBandsOfSat(const QString &_p)
     else
     {
           //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: setting to ZERO" <<  QT_ENDL;
-        rxFreqSpinBox->setValue(0);
+        updateRXFreq(0.0);
         //satBandRXComboBox->setCurrentIndex(0);
     }
       //qDebug() << "MainWindowSatTab::setBandsOfSat downLink: emiting: " << QString::number(downLink)<< QT_ENDL;
     //emit satRxFreqChanged(downLink);
-      //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - END "  << QT_ENDL;
+      //qDebug() << "MainWindowSatTab::setBandsOfSat: " << _p << " - END " ;
 }
 
 void MainWindowSatTab::addNewBand(const QString &_p)
 {
-    //qDebug() << "MainWindowSatTab::addNewBand: " << _p << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::addNewBand: " << _p;
     if (dataProxy->getIdFromBandName(_p)<0)
     {
-        //qDebug() << "MainWindowSatTab::addNewBand: Id: " <<  QString::number(dataProxy->getIdFromBandName(_p)) << QT_ENDL;
+        //qDebug() << "MainWindowSatTab::addNewBand: Id: " <<  QString::number(dataProxy->getIdFromBandName(_p));
         return;
     }
     QStringList bands;
     bands.clear();
+    int indexRX = satBandRXComboBox->currentIndex();
+    int indexTX = satBandTXComboBox->currentIndex();
 
-       //qDebug() << "MainWindowSatTab::addNewBand: RX Id: " <<  QString::number(satBandRXComboBox->count()) << QT_ENDL;
-       //qDebug() << "MainWindowSatTab::addNewBand: TX Id: " <<  QString::number(satBandTXComboBox->count()) << QT_ENDL;
+       //qDebug() << "MainWindowSatTab::addNewBand: RX Id: " <<  QString::number(satBandRXComboBox->count());
+       //qDebug() << "MainWindowSatTab::addNewBand: TX Id: " <<  QString::number(satBandTXComboBox->count());
 
     for (int i = 0; i < satBandTXComboBox->count(); i++)
     {
@@ -817,33 +791,35 @@ void MainWindowSatTab::addNewBand(const QString &_p)
     //bands.removeDuplicates();
 
     emit newBandsToBeAdded(bands);
+    satBandRXComboBox->setCurrentIndex(indexRX);
+    satBandTXComboBox->setCurrentIndex(indexTX);
     //addBands(bands);
-    //qDebug() << "MainWindowSatTab::addNewBand: 2 RX Id: " <<  QString::number(satBandRXComboBox->count()) << QT_ENDL;
-    //qDebug() << "MainWindowSatTab::addNewBand: 2 TX Id: " <<  QString::number(satBandTXComboBox->count()) << QT_ENDL;
+    //qDebug() << "MainWindowSatTab::addNewBand: 2 RX Id: " <<  QString::number(satBandRXComboBox->count());
+    //qDebug() << "MainWindowSatTab::addNewBand: 2 TX Id: " <<  QString::number(satBandTXComboBox->count());
 }
 
 void MainWindowSatTab::setModifying (const bool _m)
 {
-    //qDebug() << "MainWindowsatTab::setModifying" << QT_ENDL;
+    //qDebug() << "MainWindowsatTab::setModifying";
     modifying = _m;
 }
 
 void MainWindowSatTab::slotReturnPressed()
 {
-    //qDebug() << "MainWindowsatTab::slotReturnPressed" << QT_ENDL;
+    //qDebug() << "MainWindowsatTab::slotReturnPressed";
     emit returnPressed();
 }
 
 void MainWindowSatTab::slotSatKeepThisDataClicked()
 {
-    //qDebug() << Q_FUNC_INFO << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO;
     if (keepThisDataForNextQSOQcheckbox->isChecked())
     {
-        //qDebug() << Q_FUNC_INFO << ": True" << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << ": True";
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << ": False" << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << ": False";
     }
     slotSatNameComboBoxChanged();
 }
@@ -851,8 +827,8 @@ void MainWindowSatTab::slotSatKeepThisDataClicked()
 void MainWindowSatTab::autofillSatMode()
 {
     //qDebug() << Q_FUNC_INFO ;
-    QString downLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(rxFreqSpinBox->value()));
-    QString upLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(txFreqSpinBox->value()));
+    QString downLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(freqRX));
+    QString upLinkBand = bandToLetter(dataProxy->getBandNameFromFreq(freqTX));
     satModeLineEdit->setText(upLinkBand + "/" + downLinkBand);
 }
 
@@ -926,3 +902,4 @@ bool MainWindowSatTab::getDarkMode()
         return false;
     }
 }
+
