@@ -32,12 +32,13 @@
 #include <QWidget>
 #include <QtWidgets>
 #include "../dataproxy_sqlite.h"
-#include "../locator.h"
+//#include "../locator.h"
 #include "../utilities.h"
 
 class MainWindowSatTab : public QWidget
 {
     Q_OBJECT
+    friend class tst_MainWindowSatTab;
 public:
     explicit MainWindowSatTab(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainWindowSatTab();
@@ -50,6 +51,7 @@ public:
     QString getOtherSatName();
     QString getSatMode();
     double getRXFreq();
+    //double getTXFreq();
     void setSatMode(const QString &_t);
 
     bool getRepeatThis();
@@ -60,8 +62,10 @@ public:
 
     void setUpLinkFreq(const double _t);
     void setDownLinkFreq(const double _t);
+    //void updateTXFreq(const double _f);
+    //void updateRXFreq(const double _f);
 
-    void setLocator(const QString &_t);
+    //void setLocator(const QString &_t);
     void refreshData();
     void setModifying (const bool _m);
     void setKeep(const bool _b);
@@ -79,18 +83,18 @@ signals:
     void satRxFreqChanged(const double _p);
     void satTXFreqNeeded(const double _p);
     void satRXFreqNeeded(const double _p);
-    void dxLocatorChanged(const QString &_p);
+    //void dxLocatorChanged(const QString &_p);
     void returnPressed();
 
 private slots:
     void slotSatNameTextChanged();
     void slotSatModeTextChanged();
-    void slotSatDXLocTextChanged();
+    //void slotSatDXLocTextChanged();
     void slotSatNameComboBoxChanged();
     void slotSatBandRXComboBoxChanged();
     void slotSatBandTXComboBoxChanged();
-    void slotSatFreqRXChanged(const double _f);
-    void slotSatFreqTXChanged(const double _f);
+    //void slotSatFreqRXChanged(const double _f);
+    //void slotSatFreqTXChanged(const double _f);
     void slotReturnPressed();
     void slotSatKeepThisDataClicked();
 
@@ -103,29 +107,28 @@ private:
     void addNewBand(const QString &_p);
     void setUpLink(const QString &_t);
     QString bandToLetter(const QString &_band);
-
+    void updateTXFreq(const double _f);
+    void updateRXFreq(const double _f);
     void autofillSatMode();
 
 
     QLineEdit *satNameLineEdit;
     QLineEdit *satModeLineEdit;
-    QLineEdit *satDXLocatorLineEdit;
+    //QLineEdit *satDXLocatorLineEdit;
     QLabel *satOtherLabel;
     QCheckBox *keepThisDataForNextQSOQcheckbox;
-    //QComboBox *satNameComboBox;
-    //QPushButton *satNamePushButon;
-    //QComboBox *satNameComboBox, *satModeComboBox;
+
     QComboBox *satNameComboBox;
     QComboBox *satBandTXComboBox, *satBandRXComboBox;
     QStringList satNames, satModes;
     QStringList satellitesList;
-    //bool txFreqBeingAutoChanged, rxFreqBeingAutoChanged, updatingBands;
-    bool updatingBands;
+
+    bool updatingBands, updatingSat;
     QPalette palRed, palBlack, palWhite; // To paint Text in red or black(normal)
 
-    QDoubleSpinBox *txFreqSpinBox, *rxFreqSpinBox;
+    //QDoubleSpinBox *txFreqSpinBox, *rxFreqSpinBox;
     DataProxy_SQLite *dataProxy;
-    Locator *locator;
+
     Utilities *util;
     double freqTX, freqRX;
 
