@@ -43,14 +43,14 @@
 
 int main(int argc, char *argv[])
 {
-    //qDebug() << "KLog Main: Start! " << QT_ENDL;
-    //qDebug() << "KLog Main: " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString() << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  Start! ";
+    //qDebug() << Q_FUNC_INFO << " -  " << QSslSocket::supportsSsl() << QSslSocket::sslLibraryBuildVersionString() << QSslSocket::sslLibraryVersionString();
     QT_REQUIRE_VERSION(argc, argv, "5.9")
     //qDebug() << QT_VERSION_STR;
 
     QDir d1 = QDir();
     //QCoreApplication::setApplicationVersion(QString(APP_VERSION));
-    //qDebug() << "KLog Main STARTED: " << version << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - STARTED: ";
     Utilities util(Q_FUNC_INFO);
     QStringList arguments;
     QTextStream cout(stdout);
@@ -68,7 +68,7 @@ int main(int argc, char *argv[])
     app.setOrganizationDomain("klog.xyz");
     app.setApplicationVersion(QString(APP_VERSION));
     QString version = QCoreApplication::applicationVersion();
-    //qDebug() << "KLog Main: -10 " << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  -10 ";
     // Now we check if the user is executing from the command line
     arguments.clear();
     arguments << app.arguments();
@@ -76,42 +76,42 @@ int main(int argc, char *argv[])
     {
         if (arguments.contains("-h"))
         {
-            //cout << "Usage: klog [OPTION]... [FILE]..." << QT_ENDL;
+            //cout << "Usage: klog [OPTION]... [FILE]...";
 
-            cout << "Usage: klog [OPTION]..." << QT_ENDL;
-            cout << "Options:" << QT_ENDL;
-            cout << "     -?           Display this help" << QT_ENDL;
-            cout << "     -h           Display this help" << QT_ENDL;
-            cout << "     -v           Display program version" << QT_ENDL;
+            cout << "Usage: klog [OPTION]...";
+            cout << "Options:";
+            cout << "     -?           Display this help";
+            cout << "     -h           Display this help";
+            cout << "     -v           Display program version";
 
-            //cout << "     -e <file>    Export Adif file <file>" << QT_ENDL;
+            //cout << "     -e <file>    Export Adif file <file>";
         }
         else if (arguments.contains("-?"))
         {
-            cout << "Usage: klog [OPTION]..." << QT_ENDL;
-            cout << "Options:" << QT_ENDL;
-            cout << "     -?           Display this help" << QT_ENDL;
-            cout << "     -h           Display this help" << QT_ENDL;
-            cout << "     -v           Display program version" << QT_ENDL;
+            cout << "Usage: klog [OPTION]...";
+            cout << "Options:";
+            cout << "     -?           Display this help";
+            cout << "     -h           Display this help";
+            cout << "     -v           Display program version";
         }
         else if (arguments.contains("-v"))
         {
-            cout << "Version: KLog-" << app.applicationVersion() << QT_ENDL;
+            cout << "Version: KLog-" << app.applicationVersion();
 
         }
         else
         {
-            cout << "Usage: klog [OPTION]..." << QT_ENDL;
-            cout << "Options:" << QT_ENDL;
-            cout << "     -?           Display this help" << QT_ENDL;
-            cout << "     -h           Display this help" << QT_ENDL;
-            cout << "     -v           Display program version" << QT_ENDL;
+            cout << "Usage: klog [OPTION]...";
+            cout << "Options:";
+            cout << "     -?           Display this help";
+            cout << "     -h           Display this help";
+            cout << "     -v           Display program version";
         }
         app.quit();
         return 0;
     }
-    //qDebug() << "KLog Main: Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-    //qDebug() << "KLog Main: Detected language: " << (QLocale::system().name()).left(2) << ".qm" << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  Start of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss");
+    //qDebug() << Q_FUNC_INFO << " -  Detected language: " << (QLocale::system().name()).left(2) << ".qm";
     // Translations begin
     QTranslator qtTranslator;
     qtTranslator.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)); /* Flawfinder: ignore */
@@ -122,8 +122,8 @@ int main(int argc, char *argv[])
     //QString msgOSFilePath = QString();        // The OS depending part of the message to be printed if no translation is found.
 
     #if defined(Q_OS_WIN)
-        //qDebug() << "KLog WIN " << QT_ENDL;
-        //qDebug() << "KLog Main: -20 - WIN" << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - WIN ";
+        //qDebug() << Q_FUNC_INFO << " - 20 - WIN";
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm"); /* Flawfinder: ignore */
@@ -140,9 +140,9 @@ int main(int argc, char *argv[])
             missingTranslation = true;
             //msgOSFilePath = QCoreApplication::applicationDirPath() + "/translations/" ;
         }
-      //qDebug() << "KLog Main: -20 - end WIN " << QT_ENDL;
+      //qDebug() << Q_FUNC_INFO << " -  -20 - end WIN ";
     #elif defined(Q_OS_OSX)
-    //qDebug() << "KLog OSX " << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  OSX ";
 
         if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" +  (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
@@ -157,19 +157,19 @@ int main(int argc, char *argv[])
             missingTranslation = true;
         }
     #else
-           //qDebug() << "KLog OTHER OS: " << (QLocale::system()).name() << QT_ENDL;
+           //qDebug() << Q_FUNC_INFO << " - OTHER OS: " << (QLocale::system()).name();
         if (QFile::exists("klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
             myappTranslator.load("klog_" + (QLocale::system().name()).left(2)); /* Flawfinder: ignore */
         }
         else if (QFile::exists("/usr/share/klog/translations/klog_" + (QLocale::system().name()).left(2) + ".qm") ) /* Flawfinder: ignore */
         {
-               //qDebug() << "KLog OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2) << QT_ENDL; /* Flawfinder: ignore */
+               //qDebug() << Q_FUNC_INFO << " - OTHER -2: " << "/usr/share/klog/klog_" + (QLocale::system().name()).left(2); /* Flawfinder: ignore */
             myappTranslator.load("/usr/share/klog/translations/klog_" + (QLocale::system().name()));  /* Flawfinder: ignore */
         }
         else if (QFile::exists(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm")) /* Flawfinder: ignore */
         {
-            //qDebug() << "KLog OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - OTHER -3: " << QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2);
             myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name())); /* Flawfinder: ignore */
         }
 
@@ -184,10 +184,10 @@ int main(int argc, char *argv[])
         }
 
     #endif
-    //qDebug() << "KLog Main: -40 " << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  -40 ";
     if (missingTranslation)
         {
-            //qDebug() << "KLog Main: Translation missing! " << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " -  Translation missing! ";
             QMessageBox msgBox;
             QString urlTranslate = QString();
             urlTranslate = "<p><a href=\"https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.\">TRANSLATE</a></p>";
@@ -210,10 +210,10 @@ int main(int argc, char *argv[])
 
         }
 
-    //qDebug() << "KLog Main-1" << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - 1" << (QTime::currentTime()).toString("HH:mm:ss") ;
 
     app.installTranslator(&myappTranslator);
-    //qDebug() << "KLog Main: End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  End of translation activities: "<< (QTime::currentTime()).toString("HH:mm:ss");
     // Traslations end
 
     /* Application Singleton
@@ -268,146 +268,88 @@ int main(int argc, char *argv[])
 
     // END OF Application Singleton
 
-    QString configFileName, klogDir;
+    QString klogDir = util.getHomeDir();
+    //configFileName = util.getCfgFile();
 
-    klogDir = util.getHomeDir();
-    configFileName = util.getCfgFile();
+    //qDebug() << Q_FUNC_INFO << " - 10";
 
-    //qDebug() << "KLog Main-10" << QT_ENDL;
-
-    //qDebug() << "KLog Main: Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< QT_ENDL;;
+    //qDebug() << Q_FUNC_INFO << " - Setting klog dir: " << (QTime::currentTime()).toString("HH:mm:ss")<< QT_ENDL;;
     if (!QDir::setCurrent (klogDir) )
     {
-        //qDebug() << "MAIN:  KLogDir does not exist.... creating " << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - KLogDir does not exist.... creating ";
         if (d1.mkdir(klogDir))
         {
             if (QDir::setCurrent (klogDir) )
             {
-                    //qDebug() << "MAIN:  KLogDir has just been created and pointed " << QT_ENDL;
+                    //qDebug() << Q_FUNC_INFO << " - KLogDir has just been created and pointed ";
             }
         }
     }
-    //qDebug() << "KLog Main: Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  Setting klog dir - finished: " << (QTime::currentTime()).toString("HH:mm:ss");
 
-    //qDebug() << "KLog Main: Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " -  Setting config file: " << (QTime::currentTime()).toString("HH:mm:ss") ;
     QPixmap pixmap(":img/klog_512x512.png");
-    //qDebug() << "KLog Main-51" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - 51" << (QTime::currentTime()).toString("HH:mm:ss");
     QSplashScreen splash(pixmap);
 
-    if(!QFile::exists(configFileName))
-    {
-        //qDebug() << "MAIN:  Starting wizard... " << QT_ENDL;
 
+    if (!((QFile::exists(util.getCfgFile ()))))
+    {
+        //qDebug() << Q_FUNC_INFO << " -  Starting wizard... ";
         StartWizard *wizard = new StartWizard(klogDir, version);
         wizard->setModal(true);
-        //int inMemory = wizard->exec();
         wizard->exec();
-        //qDebug() << "MAIN: Wizard inMemory: " << QString::number(inMemory) << QT_ENDL;
-        //inMemory = 1;
-
-        //if (inMemory == 1)
-        //{
-            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << QT_ENDL;
-            MainWindow mw(klogDir, version);
-            mw.init();
-            splash.finish(&mw);
-            //mw.checkIfNewVersion();
-            //mw.recommendBackupIfNeeded();
-            mw.showNotWar();
-            mw.show();
-            return app.exec();
-        //}
-        /*
-        else
-        {
-               //qDebug() << "MAIN: Wizard cancelled " << QString::number(inMemory) << " ... should close " << QT_ENDL;
-
-            QMessageBox msgBox;
-            msgBox.setText(QObject::tr("Install wizard was canceled before completing..."));
-            msgBox.setInformativeText(QObject::tr("Do you want to remove the KLog dir from your disk?"));
-            msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No );
-            msgBox.setDefaultButton(QMessageBox::Yes);
-            int ret = msgBox.exec();
-
-            switch (ret)
-            {
-              case QMessageBox::Yes:
-                if (QDir::setCurrent (QDir::homePath()) )
-                {
-                    if (d1.remove(klogDir))
-                    {
-                        QMessageBox msgBox;
-                        msgBox.setText(QObject::tr("Your KLog dir has been removed") +"\n\n" + QObject::tr("Thank you for running KLog!"));
-                        msgBox.exec();
-                    }
-                    else
-                    {
-                        QMessageBox msgBox;
-                        msgBox.setText(QObject::tr("I could not remove your KLog dir. You should do it manually if you want it removed from your hard disk.") +"\n\n" + QObject::tr("Thank you for running KLog!"));
-                        msgBox.exec();
-                    }
-                }
-                else
-                {
-                    QMessageBox msgBox;
-                    msgBox.setText(QObject::tr("Your KLog dir could not be removed. You should do it manually if you want it removed from your hard disk.") +"\n\n" + QObject::tr("Thank you for running KLog!"));
-                    msgBox.exec();
-                }
-            break;
-            case QMessageBox::No:
-                QMessageBox msgBox;
-                msgBox.setText(QObject::tr("Remember that your KLog dir is on your system...") + "\n\n" + QObject::tr("Thank you for running KLog!"));
-                msgBox.exec();
-            break;
-            }
-            return 0;
-        }
-        */
     }
     else
     {
-        //qDebug() << "Main: Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " -  Start of DB Activities" << (QTime::currentTime()).toString("HH:mm:ss");
         DataBase *db = new DataBase(Q_FUNC_INFO, version, util.getKLogDBFile());
-        //qDebug() << "Main: After Start of DB Activities" << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " -  After Start of DB Activities";
         if (!db->createConnection(Q_FUNC_INFO))
         {
-            //qDebug() << "Main: Conection not created" << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - Conection not created";
             return -1; // Exits with an error; no DB has been created
         }
         else
         {
-            //qDebug() << "Main: DB to be updated" << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - DB to be updated";
             db->updateIfNeeded(); // Check if we need to update the DB
-            //qDebug() << "Main: DB Updated" << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " - DB Updated";
         }
-        //qDebug() << "Main: DB Updated" << QT_ENDL;
-        //qDebug() << "KLog Main-98" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - DB Updated";
+        //qDebug() << Q_FUNC_INFO << " - 98" << (QTime::currentTime()).toString("HH:mm:ss");
         db->~DataBase();
-        //qDebug() << "KLog Main-99" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.show();
-        //qDebug() << "KLog Main-100" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.showMessage ("Creating window...");
-        MainWindow mw(klogDir, version);
-        //qDebug() << "KLog Main-101" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.showMessage ("Initializing window...");
-        mw.init();
-        //qDebug() << "KLog Main-102" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.showMessage ("Checking for new versions...");
-        mw.checkIfNewVersion();
-        splash.showMessage ("Checking if backup is needed...");
-        //qDebug() << "KLog Main-103" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        mw.recommendBackupIfNeeded();
-        splash.showMessage ("Showing window...");
-        //qDebug() << "KLog Main-104" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        mw.show();
-        //qDebug() << "KLog Main-105" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        splash.finish(&mw);
-        mw.showNotWar();
-        //qDebug() << "KLog Main-106" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
-        return app.exec();
-        //qDebug() << "KLog Main-107" << (QTime::currentTime()).toString("HH:mm:ss") << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " - 99" << (QTime::currentTime()).toString("HH:mm:ss");
     }
-        //qDebug() << "KLog Main-END: " << (QTime::currentTime()).toString("HH:mm:ss")  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << " - 100 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.show();
+    //qDebug() << Q_FUNC_INFO << " - 101 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.showMessage ("Creating window...");
+    //qDebug() << Q_FUNC_INFO << " - 102 " << (QTime::currentTime()).toString("HH:mm:ss");
+    MainWindow mw(version);
+    //qDebug() << Q_FUNC_INFO << " - 103 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.showMessage ("Initializing window...");
+    //qDebug() << Q_FUNC_INFO << " - 104 " << (QTime::currentTime()).toString("HH:mm:ss");
+    mw.init();
+    //qDebug() << Q_FUNC_INFO << " - 105 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.showMessage ("Checking for new versions...");
+    //qDebug() << Q_FUNC_INFO << " - 106 " << (QTime::currentTime()).toString("HH:mm:ss");
+    mw.checkIfNewVersion();
+    //qDebug() << Q_FUNC_INFO << " - 107 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.showMessage ("Checking if backup is needed...");
+    //qDebug() << Q_FUNC_INFO << " - 108 " << (QTime::currentTime()).toString("HH:mm:ss");
+    mw.recommendBackupIfNeeded();
+    //qDebug() << Q_FUNC_INFO << " - 109 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.showMessage ("Showing window...");
+    //qDebug() << Q_FUNC_INFO << " - 110 " << (QTime::currentTime()).toString("HH:mm:ss");
+    mw.show();
+    //qDebug() << Q_FUNC_INFO << " - 111 " << (QTime::currentTime()).toString("HH:mm:ss");
+    splash.finish(&mw);
+    //qDebug() << Q_FUNC_INFO << " - 112 " << (QTime::currentTime()).toString("HH:mm:ss");
+    mw.showNotWar();
+    //qDebug() << Q_FUNC_INFO << " - 113 " << (QTime::currentTime()).toString("HH:mm:ss");
+    //qDebug() << Q_FUNC_INFO << " - END";
+    return app.exec();
 }
 
 
