@@ -29,9 +29,9 @@
 
 MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) : QWidget(parent)
 {
-      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget " << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget ";
     logEvent (Q_FUNC_INFO, "Start", Debug);
-
+    modifyingBands = false;
     upAndRunning = false;
     dataProxy = dp;
     qrzLineEdit = new QLineEdit;
@@ -43,6 +43,7 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     enabledCR = realtimeCheckBox->backgroundRole();
     manualModeCheckBox = new QCheckBox;
 
+    QRZButton = new QPushButton("QRZ");
     OKButton = new QPushButton(tr("&Add"), this);
     clearButton = new QPushButton(tr("&Clear"), this);
     timer = new QTimer(this);
@@ -56,7 +57,7 @@ MainQSOEntryWidget::MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent) :
     setInitialData();
     //installEventFilter (this);
     logEvent (Q_FUNC_INFO, "END", Debug);
-      //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::MainQSOEntryWidget: - END";
 }
 
 MainQSOEntryWidget::~MainQSOEntryWidget()
@@ -77,7 +78,7 @@ void MainQSOEntryWidget::slotRealTimeButtonResize()
 */
 void MainQSOEntryWidget::createUI()
 {
-      //qDebug()<< "MainQSOEntryWidget::createUI" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::createUI";
     logEvent (Q_FUNC_INFO, "Start", Debug);
     qrzLineEdit->setToolTip(tr("Callsign of the QSO."));
     bandComboBox->setToolTip(tr("Band of the QSO."));
@@ -86,6 +87,7 @@ void MainQSOEntryWidget::createUI()
     timeEdit->setToolTip(tr("Time of the QSO."));
     OKButton->setToolTip(tr("Add the QSO to the log."));
     clearButton->setToolTip(tr("Clears the QSO entry."));
+    QRZButton->setToolTip(tr("Look up info about the current callsign on qrz.com"));
     realtimeCheckBox->setToolTip(tr("KLog will show real time if enabled."));
     realtimeCheckBox->setText (tr("Real time"));
     //realtimeButton->setToolTip(tr("KLog will show real time if enabled."));
@@ -115,6 +117,7 @@ void MainQSOEntryWidget::createUI()
     qrzgroupBox->setLayout(qrzvbox);
 
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
+    buttonsLayout->addWidget(QRZButton);
     buttonsLayout->addWidget(OKButton);
     buttonsLayout->addWidget(clearButton);
     dateEdit->setCalendarPopup (true);;
@@ -141,20 +144,21 @@ void MainQSOEntryWidget::createUI()
     connect(bandComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotBandComboBoxChanged(QString) ) ) ;
     connect(modeComboBox, SIGNAL(currentIndexChanged (QString)), this, SLOT(slotModeComboBoxChanged(QString) ) ) ;
 
-    connect(OKButton, SIGNAL(clicked()), this, SLOT(slotOKButtonClicked() ) );
+    connect(OKButton, SIGNAL(clicked()), this, SLOT(slotOKButtonClicked()));
+    connect(clearButton, SIGNAL(clicked()), this, SLOT(slotClearButtonClicked()));
+    connect(QRZButton, SIGNAL(clicked()), this, SLOT(slotQRZButtonClicked()));
 
-    connect(clearButton, SIGNAL(clicked()), this, SLOT(slotClearButtonClicked() ) );
     connect(timer, SIGNAL(timeout()), this, SLOT(slotUpdateTime()) );
     //connect(realtimeButton, SIGNAL(clicked()), this, SLOT(slotRealtimeButtonClicked()) );
     connect(realtimeCheckBox, SIGNAL(clicked()), this, SLOT(slotCheckBoxClicked()));
     connect(manualModeCheckBox, SIGNAL(clicked()), this, SLOT(slotManualModeCheckBoxClicked()));
-    //qDebug()<< "MainQSOEntryWidget::createUI-END" << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::createUI-END";
 
     QWidget::setTabOrder (qrzLineEdit, dateEdit);
     QWidget::setTabOrder (dateEdit, timeEdit);
 
     logEvent (Q_FUNC_INFO, "END", Debug);
-    //qDebug() << Q_FUNC_INFO << ": (" << QString::number(this->size ().width ()) << "/" << QString::number(this->size ().height ()) << ")" ;
+     //qDebug() << Q_FUNC_INFO << ": (" << QString::number(this->size ().width ()) << "/" << QString::number(this->size ().height ()) << ")" ;
 }
 
 void MainQSOEntryWidget::setShowSeconds(const bool &t)
@@ -179,6 +183,7 @@ void MainQSOEntryWidget::setLogLevel (const DebugLogLevel _b)
 void MainQSOEntryWidget::setCallValidation (const bool _b)
 {
     util->setCallValidation(_b);
+    dataProxy->setCallValidation(_b);
 }
 
 void MainQSOEntryWidget::slotCheckBoxClicked()
@@ -248,30 +253,30 @@ void MainQSOEntryWidget::setCleaning (const bool _c)
 void MainQSOEntryWidget::slotQRZTextChanged()
 {
     logEvent (Q_FUNC_INFO, "Start: " + qrzLineEdit->text(), Debug);
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######" << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << "###### START ######";
     logEvent (Q_FUNC_INFO, "Start", Debug);
 
     if ((qrzLineEdit->text()).length()<1)
     {
-       //qDebug() << Q_FUNC_INFO << ": qrz length <1";
+        //qDebug() << Q_FUNC_INFO << ": qrz length <1";
         slotClearButtonClicked();
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ <1 - END" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ <1 - END";
     return;
     }
     int cursorP = qrzLineEdit->cursorPosition();
-   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP) << QT_ENDL;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position: " << QString::number(cursorP);
     qrzLineEdit->setText((qrzLineEdit->text()).toUpper());
     if (cleaning)
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Cleaning - END";
         logEvent (Q_FUNC_INFO, "END-2", Debug);
         return;
     }
 
     if (qrzAutoChanging)
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: qrzAutoChanging - END";
         qrzAutoChanging = false;
         logEvent (Q_FUNC_INFO, "END-3", Debug);
         return;
@@ -279,33 +284,33 @@ void MainQSOEntryWidget::slotQRZTextChanged()
 
     qrzAutoChanging = true;
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP) << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.1: " << QString::number(cursorP);
 
     if ( (qrzLineEdit->text()).endsWith(' ') )
     {/*Remove the space and moves the focus to SRX to write the RX exchange*/
         previousQRZ = (qrzLineEdit->text()).simplified();
         qrzLineEdit->setText(previousQRZ);
-       //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected" << QT_ENDL;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Space detected";
     }
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing" << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Simplifiying & Capitalizing";
     qrzLineEdit->setText(((qrzLineEdit->text())).simplified());
     qrzLineEdit->setText((qrzLineEdit->text()).remove(" "));
 
-   //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars" << QT_ENDL;
+    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars";
     //TODO: This validCharactersInCall may be removed?
     InValidCharsInPrevCall = validCharactersInCall(qrzLineEdit->text());
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 " << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for invalid chars 00 ";
     if (!util->isValidCall(qrzLineEdit->text()))
     {
         qrzLineEdit->setPalette(palRed);
         //emit showInfoLabel(tr("Callsign not valid"));
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - Red" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ not valid - Red";
         //logEvent (Q_FUNC_INFO, "END-4", Debug);
     }
     else
     {
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ is valid - Black" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: QRZ is valid - Black";
         if (getDarkMode())
         {
             qrzLineEdit->setPalette(palWhite);
@@ -319,7 +324,7 @@ void MainQSOEntryWidget::slotQRZTextChanged()
         //emit showInfoLabel(tr(""));
     }
     /*
-      //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for length" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for length";
     if (((qrzLineEdit->text()).length() < 1))
     { // If QRZ box is blank, Information labels should be cleared.
         slotClearButtonClicked();
@@ -328,56 +333,56 @@ void MainQSOEntryWidget::slotQRZTextChanged()
     }
     */
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1" << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: checking for modify or length<1";
     if (qrzSmallModDontCalculate)
     //if ((modify) || ((qrzLineEdit->text()).length() < 1) || (qrzSmallModDontCalculate))
     {
-       //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1" << QT_ENDL;
+        //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: qrzSmallModDontCalculate < 1";
         qrzSmallModDontCalculate=false;
         logEvent (Q_FUNC_INFO, "END-6", Debug);
         return;
     }
 
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running..." << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: running...";
     qrzSmallModDontCalculate = true; // A kind of flag to prevent multiple calls to this method.
     currentQrz = qrzLineEdit->text();
 
     if ((currentQrz).count('\\'))
     { // Replaces \ by / to ease operation.
-       //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /" << QT_ENDL;
+        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: Replacing \\ by /";
         currentQrz.replace(QChar('\\'), QChar('/'));
         qrzLineEdit->setText(currentQrz);
     }
 
     currentQrz = qrzLineEdit->text();
-    //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP) << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.3: " << QString::number(cursorP);
     if (cursorP>currentQrz.length())
     {// A Space that has been removed without updating the cursor
-        //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length" << QT_ENDL;
+         //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursorP > currentQRZ.length";
     }
     else
     {
-       //qDebug() << Q_FUNC_INFO << " cursorP<currentQrz.length: " << QString::number(cursorP);
+        //qDebug() << Q_FUNC_INFO << " cursorP<currentQrz.length: " << QString::number(cursorP);
 
         if (cursorP>0)
         {
             if ((currentQrz.at(cursorP-1)).isSpace())
             {
-               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP) << QT_ENDL;
+                //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.5: " << QString::number(cursorP);
                 previousQRZ = currentQrz.remove(cursorP-1, 1);
-               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP) << QT_ENDL;
+                //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.6: " << QString::number(cursorP);
                 cursorP--;
-               //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP) << QT_ENDL;
+                //qDebug()<< "MainQSOEntryWidget::slotQRZTextChanged: cursor position.7: " << QString::number(cursorP);
                 qrzLineEdit->setText(previousQRZ);
             }
         }
     }
     currentQrz = qrzLineEdit->text();
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: Emitting: " << currentQrz << QT_ENDL;
+     //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: Emitting: " << currentQrz;
     emit currentQRZSignal(currentQrz);
 
     qrzSmallModDontCalculate = false; // If the text has not been modified in this method
-    //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP);
+     //qDebug() << "MainQSOEntryWidget::slotQRZTextChanged: cursorP at the end : " << QString::number(cursorP);
     qrzLineEdit->setCursorPosition(cursorP);
     checkIfDupe(Q_FUNC_INFO);
     qrzAutoChanging = false;
@@ -392,15 +397,17 @@ void MainQSOEntryWidget::setCurrentQRZ(const QString &_qrz)
 }
 
 void MainQSOEntryWidget::slotBandComboBoxChanged(const QString &_b){
-    //qDebug() << Q_FUNC_INFO << ": " << _b;
+     //qDebug() << Q_FUNC_INFO << ": " << _b;
 
     logEvent (Q_FUNC_INFO, "Start", Debug);
+    if (modifyingBands)
+        return;
     bottomBandLimit = dataProxy->getLowLimitBandFromBandName (_b);
     upperBandLimit = dataProxy->getUpperLimitBandFromBandName (_b);
     emit bandChanged(_b);
     checkIfDupe(Q_FUNC_INFO);
     logEvent (Q_FUNC_INFO, "END", Debug);
-    //qDebug() << Q_FUNC_INFO << " - END";
+     //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void MainQSOEntryWidget::slotModeComboBoxChanged(const QString &_m)
@@ -412,6 +419,15 @@ void MainQSOEntryWidget::slotModeComboBoxChanged(const QString &_m)
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
 
+void MainQSOEntryWidget::slotQRZButtonClicked()
+{
+    if ((qrzLineEdit->text()).length()<1)
+    {
+        return;
+    }
+    util->openQrzcom(currentQrz);
+}
+
 void MainQSOEntryWidget::slotOKButtonClicked()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -425,7 +441,7 @@ void MainQSOEntryWidget::slotOKButtonClicked()
 
 void MainQSOEntryWidget::slotClearButtonClicked()
 {
-    //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked: "  << QT_ENDL;
+     //qDebug() << "MainQSOEntryWidget::slotClearButtonClicked: " ;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     setCleaning (true);
     clear();
@@ -440,7 +456,7 @@ void MainQSOEntryWidget::clear()
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
 
-    //qDebug() << Q_FUNC_INFO << QT_ENDL;
+     //qDebug() << Q_FUNC_INFO;
 
     //cleaning = true;
 
@@ -454,7 +470,7 @@ void MainQSOEntryWidget::clear()
 
 void MainQSOEntryWidget::setInitialData()
 {
-      //qDebug()<< "MainQSOEntryWidget::setInitialData" << QT_ENDL;
+       //qDebug()<< "MainQSOEntryWidget::setInitialData";
     logEvent (Q_FUNC_INFO, "Start", Debug);
     //Default band/modes
     modify = false;
@@ -469,7 +485,7 @@ void MainQSOEntryWidget::setInitialData()
     bands.clear();
     modes.clear();
     bands << "10M" << "15M" << "20M" << "40M" << "80M" << "160M";
-    modes << "SSB" << "CW" << "RTTY";
+    modes << "SSB" << "CW";
 
     setBands(bands);
     setModes(modes);
@@ -481,27 +497,27 @@ void MainQSOEntryWidget::setInitialData()
     timeEdit->setTime(QTime::currentTime());
 
     UTCTime = true;
-    // //qDebug()ime = true;
+    //  //qDebug()ime = true;
 
     timer->start(1000);
 
     logEvent (Q_FUNC_INFO, "END", Debug);
-     //qDebug()<< "MainQSOEntryWidget::setInitialData-END" << QT_ENDL;
+      //qDebug()<< "MainQSOEntryWidget::setInitialData-END";
 }
 
 bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
 {
     logEvent (Q_FUNC_INFO, "Start: " + _band, Debug);
-    //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": " << _band;
     //QString _currentBand = getBand();
     if (!isBandExisting(_band))
     {// The selected frequency is of a band that is not currently selected
         QString _currentBand = bandComboBox->currentText ();
-        //qDebug() << Q_FUNC_INFO << ":  New band found: " << _band << QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << ":  New band found: " << _band;
         if (dataProxy->getIdFromBandName(_band) > 1)
         {// Not affected if 0 (light) is the frequency
          // In this case the user should select the band in the setup
-            //qDebug() << Q_FUNC_INFO << ":  Band is valid: " << _band << QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << ":  Band is valid: " << _band;
             QStringList qsTemp;
             qsTemp.clear();
             qsTemp << bands;
@@ -509,31 +525,32 @@ bool MainQSOEntryWidget::updateBandComboBox(const QString &_band)
             qsTemp.removeDuplicates();
             bands.clear();
             bands = dataProxy->sortBandNamesBottonUp(qsTemp);
-            //qDebug() << Q_FUNC_INFO << ": Before setBands" << QT_ENDL;
+             //qDebug() << Q_FUNC_INFO << ": Before setBands";
             setBands(bands);
             bandComboBox->setCurrentIndex(bandComboBox->findText(_currentBand, Qt::MatchCaseSensitive));
-            //qDebug() << Q_FUNC_INFO << ": Band has been added : " << _band << QT_ENDL;
+             //qDebug() << Q_FUNC_INFO << ": Band has been added : " << _band;
         }
         else
         {
-            //qDebug() << Q_FUNC_INFO << ": (END) Band is NOT  valid: " <<_band<< endl;
+            //qDebug() << Q_FUNC_INFO << ": (END) Band is NOT  valid: " <<_band;
             logEvent (Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
-    //qDebug() << Q_FUNC_INFO << ": Band already existing, no need to add"  << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": Band already existing, no need to add" ;
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
 }
 
-void MainQSOEntryWidget::setBands(const QStringList _bands)
+void MainQSOEntryWidget::setBands(const QStringList &_bands)
 {
     logEvent (Q_FUNC_INFO, "Start: " + QString::number(_bands.length ()), Debug);
-    //qDebug()<< "MainQSOEntryWidget::setBands" << QT_ENDL;
-    //foreach(QString i, _bands)
-    //{
-        //qDebug()<< "MainQSOEntryWidget::setBands - received: " << i << QT_ENDL;
-    //}
+    //qDebug()<< Q_FUNC_INFO << " - Start: " << QString::number(_bands.length ());
+    modifyingBands = true;
+    foreach(QString i, _bands)
+    {
+        //qDebug()<< Q_FUNC_INFO << " - received: " << i;
+    }
     bands.clear();
     bands = _bands;
     bands.removeDuplicates();
@@ -542,13 +559,16 @@ void MainQSOEntryWidget::setBands(const QStringList _bands)
     bandComboBox->addItems(bands);
     emit validBands(_bands);
     //selectDefaultBand(true);
+    modifyingBands = false;
     logEvent (Q_FUNC_INFO, "END", Debug);
-    //qDebug()<< "MainQSOEntryWidget::setBands-END" << QT_ENDL;
+    //qDebug()<< Q_FUNC_INFO << " - END";
 }
 
-void MainQSOEntryWidget::setModes(const QStringList _modes)
+void MainQSOEntryWidget::setModes(const QStringList &_modes)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
+     //qDebug() << Q_FUNC_INFO;
+
     modes.clear();
     modes = _modes;
     modes.removeDuplicates();
@@ -568,7 +588,7 @@ QStringList MainQSOEntryWidget::getModes()
 
 bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
+     //qDebug() << Q_FUNC_INFO << ": " << QString::number(_f);
     logEvent (Q_FUNC_INFO, "Start", Debug);
     if (isRX)
     {
@@ -594,12 +614,12 @@ bool MainQSOEntryWidget::setFreq(const double _f, bool isRX)
             logEvent (Q_FUNC_INFO, "END-3", Debug);
             return true;
         }
-        //qDebug() << Q_FUNC_INFO << ": Freq is not in the current band" << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << ": Freq is not in the current band";
         QString _newBand = dataProxy->getBandNameFromFreq(_f);
-        //qDebug() << Q_FUNC_INFO << ": before setting band: " << _newBand  << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << ": before setting band: " << _newBand ;
         if (isRX)
         {
-            //qDebug() << Q_FUNC_INFO << ": RX Freq no more actions "  << QT_ENDL;
+             //qDebug() << Q_FUNC_INFO << ": RX Freq no more actions " ;
             logEvent (Q_FUNC_INFO, "END-4", Debug);
             return true;
         }
@@ -618,7 +638,7 @@ bool MainQSOEntryWidget::newBandNeededForFreq(const double _f)
     if (!updateBandComboBox (_newBand))
     {
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-        //qDebug() << Q_FUNC_INFO << " - END false";
+         //qDebug() << Q_FUNC_INFO << " - END false";
         return false;
     }
     //qDebug() << Q_FUNC_INFO << " - END true ";
@@ -628,19 +648,19 @@ bool MainQSOEntryWidget::newBandNeededForFreq(const double _f)
 
 bool MainQSOEntryWidget::setBand(const QString &_band)
 {
-    //qDebug() << Q_FUNC_INFO << ": " << _band << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << ": " << _band;
 
     logEvent (Q_FUNC_INFO, "Start: " + _band, Debug);
     if (bandComboBox->findText(_band, Qt::MatchCaseSensitive) < 0)
     {
-        //qDebug() << "MainQSOEntryWidget::setBand-1: Band not found " << _band << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << ": Band not found " << _band;
         if (!updateBandComboBox(_band))
         {
             logEvent (Q_FUNC_INFO, "END-1", Debug);
             return false;
         }
     }
-    //qDebug() << "MainQSOEntryWidget::setBand-1: Band found " << _band << QT_ENDL;
+     //qDebug() << "MainQSOEntryWidget::setBand-1: Band found " << _band;
     bandComboBox->setCurrentIndex(bandComboBox->findText(_band, Qt::MatchCaseSensitive));
     logEvent (Q_FUNC_INFO, "END", Debug);
     return true;
@@ -649,16 +669,16 @@ bool MainQSOEntryWidget::setBand(const QString &_band)
 bool MainQSOEntryWidget::setMode(const QString &_mode)
 {
     logEvent (Q_FUNC_INFO, "Start" + _mode, Debug);
-    //qDebug() << "MainQSOEntryWidget::setMode: " << _mode;
+     //qDebug() << "MainQSOEntryWidget::setMode: " << _mode;
     if (modeComboBox->findText(_mode, Qt::MatchCaseSensitive) < 0)
     {
-        //qDebug() << "MainQSOEntryWidget::setMode NOT found";
+         //qDebug() << "MainQSOEntryWidget::setMode NOT found";
         logEvent (Q_FUNC_INFO, "END-1", Debug);
         return false;
     }
     else
     {
-        //qDebug() << "MainQSOEntryWidget::setMode Updated";
+         //qDebug() << "MainQSOEntryWidget::setMode Updated";
         modeComboBox->setCurrentIndex(modeComboBox->findText(_mode, Qt::MatchCaseSensitive));
         logEvent (Q_FUNC_INFO, "END-2", Debug);
         return true;
@@ -668,7 +688,7 @@ bool MainQSOEntryWidget::setMode(const QString &_mode)
 bool MainQSOEntryWidget::setQRZ(const QString &_qrz)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz << QT_ENDL;
+     //qDebug() << "MainQSOEntryWidget::setQRZ: " << _qrz;
     //TODO: Add validations to prevent that non valid qrz are sent from the outside of this function or at least manage this appropriately.
     qrzLineEdit->setText(_qrz.toUpper());
     logEvent (Q_FUNC_INFO, "END", Debug);
@@ -687,7 +707,7 @@ bool MainQSOEntryWidget::setDateTime(const QDateTime _date)
     }
     else
     {
-        //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE" << QT_ENDL;
+         //qDebug() << "MainQSOEntryWidget::setDate - NO VALID DATE";
         logEvent (Q_FUNC_INFO, "END-2", Debug);
         return false;
     }
@@ -729,7 +749,7 @@ QString MainQSOEntryWidget::getBand(const int _b)
     if (_b<0)
     {
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-        //qDebug() << "MainQSOEntryWidget::getBand(1): " << bandComboBox->currentText()<< QT_ENDL;
+        //qDebug() << Q_FUNC_INFO << " (1): " << bandComboBox->currentText()<< QT_ENDL;
         return bandComboBox->currentText();
     }
     else
@@ -737,13 +757,13 @@ QString MainQSOEntryWidget::getBand(const int _b)
         if (bandComboBox->count()>=_b)
         {
             logEvent (Q_FUNC_INFO, "END-2", Debug);
-            //qDebug() << "MainQSOEntryWidget::getBand(2): " << bandComboBox->currentText()<< QT_ENDL;
+            //qDebug() << Q_FUNC_INFO << " (2): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->itemText(_b);
         }
         else
         {
             logEvent (Q_FUNC_INFO, "END-3", Debug);
-            //qDebug() << "MainQSOEntryWidget::getBand(3): " << bandComboBox->currentText()<< QT_ENDL;
+             //qDebug() << Q_FUNC_INFO << " (3): " << bandComboBox->currentText()<< QT_ENDL;
             return bandComboBox->currentText();
         }
     }
@@ -877,7 +897,7 @@ void MainQSOEntryWidget::slotUpdateTime()
     //logEvent (Q_FUNC_INFO, "Start", Debug);
     if ( (!modify) && (realtimeCheckBox->isChecked())  )
     {
-        //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update" << QT_ENDL;
+        //qDebug()<< "MainQSOEntryWidget::slotUpdateTime - Real Time & update";
         setDateAndTimeInternally();
     }
     //logEvent (Q_FUNC_INFO, "END", Debug);
@@ -901,7 +921,7 @@ void MainQSOEntryWidget::setDateAndTimeInternally()
 
 bool MainQSOEntryWidget::validCharactersInCall(const QString &_qrz)
 {
-    //qDebug()<< "MainQSOEntryWidget::validCharactersInCall: " << _qrz << QT_ENDL;
+     //qDebug()<< "MainQSOEntryWidget::validCharactersInCall: " << _qrz;
     logEvent (Q_FUNC_INFO, "Start", Debug);
     for (int i = 0; i<_qrz.size()-1;i++)
     {
@@ -933,17 +953,17 @@ bool MainQSOEntryWidget::isModeExisting(const QString &_m)
 bool MainQSOEntryWidget::isBandExisting(const QString &_b)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
-    //qDebug() << Q_FUNC_INFO << ": " << _b << QT_ENDL;
+     //qDebug() << Q_FUNC_INFO << ": " << _b;
     if (bandComboBox->findText(_b, Qt::MatchCaseSensitive) >= 0)
     {
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-        //qDebug() << Q_FUNC_INFO << " - END true" << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << " - END true";
         return true;
     }
     else
     {
         logEvent (Q_FUNC_INFO, "END-2", Debug);
-        //qDebug() << Q_FUNC_INFO << " - END false" << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << " - END false";
         return false;
     }
 }
@@ -957,25 +977,25 @@ void MainQSOEntryWidget::setUpAndRunning(const bool _u)
 
 void MainQSOEntryWidget::selectDefaultBand(bool _init)
 {
-      //qDebug() << "MainQSOEntryWidget::selectDefaultBand" << QT_ENDL;
+       //qDebug() << "MainQSOEntryWidget::selectDefaultBand";
     logEvent (Q_FUNC_INFO, "Start", Debug);
     if ((upAndRunning) || (!_init))
     {
         logEvent (Q_FUNC_INFO, "END-1", Debug);
-          //qDebug() << "MainQSOEntryWidgetselectDefaultBand-END-1" << QT_ENDL;
+           //qDebug() << "MainQSOEntryWidgetselectDefaultBand-END-1";
         return;
     }
     QString aux;
     aux = QString();
     int defaultBand = dataProxy->getMostUsedBand(-1); //TODO: The log could be defined here
-      //qDebug() << "MainQSOEntryWidget::selectDefaultBand: " << QString::number(defaultBand) << dataProxy->getNameFromBandId (defaultBand)<< QT_ENDL;
+       //qDebug() << "MainQSOEntryWidget::selectDefaultBand: " << QString::number(defaultBand) << dataProxy->getNameFromBandId (defaultBand)<< QT_ENDL;
     if (defaultBand<1)
     {
         defaultBand = dataProxy->getIdFromBandName(getBand(0));
     }
 
     aux = dataProxy->getNameFromBandId(defaultBand);
-    //qDebug() << Q_FUNC_INFO << ": before setting band: " << aux << QT_ENDL;
+     //qDebug() << Q_FUNC_INFO << ": before setting band: " << aux;
     setBand(aux);
     logEvent (Q_FUNC_INFO, "END", Debug);
 }
@@ -989,7 +1009,7 @@ void MainQSOEntryWidget::selectDefaultMode(bool _init)
         return;
     }
     int defaultMode = dataProxy->getMostUsedMode(-1); //TODO: The log could be defined here
-      //qDebug() << "MainQSOEntryWidgetselectDefaultMode: " << QString::number(defaultMode) << QT_ENDL;
+       //qDebug() << "MainQSOEntryWidgetselectDefaultMode: " << QString::number(defaultMode);
 
     if (defaultMode < 1)
     {
@@ -998,9 +1018,9 @@ void MainQSOEntryWidget::selectDefaultMode(bool _init)
     setMode(dataProxy->getNameFromSubModeId(defaultMode));
     //modeComboBox->setCurrentIndex(modeComboBox->findText(dataProxy->getNameFromSubModeId(defaultMode)));
 
-     //qDebug() << "MainQSOEntryWidgetselectDefaultMode3: " << QString::number(defaultMode) << QT_ENDL;
+      //qDebug() << "MainQSOEntryWidgetselectDefaultMode3: " << QString::number(defaultMode);
     logEvent (Q_FUNC_INFO, "END", Debug);
-     //qDebug() << "MainQSOEntryWidgetselectDefaultMode-END" << QT_ENDL;
+      //qDebug() << "MainQSOEntryWidgetselectDefaultMode-END";
 }
 
 void MainQSOEntryWidget::setDuplicatedQSOSlot (const int _secs)
@@ -1015,8 +1035,9 @@ void MainQSOEntryWidget::setDuplicatedQSOSlot (const int _secs)
 
 void MainQSOEntryWidget::checkIfDupe(const QString &_func)
 {
+    Q_UNUSED(_func);
 #ifdef QT_DEBUG
-   //qDebug() << Q_FUNC_INFO << "(" << _func << ")" << QT_ENDL;
+    //qDebug() << Q_FUNC_INFO << "(" << _func << ")";
 #else
 #endif
     logEvent (Q_FUNC_INFO, "Start", Debug);
@@ -1026,13 +1047,13 @@ void MainQSOEntryWidget::checkIfDupe(const QString &_func)
 
     if ((dataProxy->isThisQSODuplicated(Q_FUNC_INFO, qrzLineEdit->text(), _dateTime, dataProxy->getIdFromBandName(bandComboBox->currentText()), dataProxy->getIdFromModeName(modeComboBox->currentText()), duplicatedQSOSlotInSecs).length()<2) || modify)
     {
-        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << QT_ENDL;
-        //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify) << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << " - NOT DUPE ";
+         //qDebug() << Q_FUNC_INFO << " - Modify: " << util->boolToQString(modify);
         qrzgroupBox->setTitle(tr("Callsign"));
     }
     else
     {
-        //qDebug() << Q_FUNC_INFO << " - NOT DUPE " << QT_ENDL;
+         //qDebug() << Q_FUNC_INFO << " - NOT DUPE ";
         qrzgroupBox->setTitle(tr("DUPE", "Translator: DUPE is a common world for hams. Do not translate of not sure"));
     }
     logEvent (Q_FUNC_INFO, "END", Debug);
@@ -1048,7 +1069,7 @@ void MainQSOEntryWidget::slotStartDelayInputTimer()
     }
     if (qrzLineEdit->text ().length ()<1)
     {
-        //qDebug() << Q_FUNC_INFO;
+         //qDebug() << Q_FUNC_INFO;
         slotClearButtonClicked ();
         logEvent (Q_FUNC_INFO, "END-2", Debug);
         return;
@@ -1069,7 +1090,7 @@ void MainQSOEntryWidget::slotDelayInputTimedOut()
     QString text = qrzLineEdit->text();
     if( text != lastQrz)
     {
-        //qDebug() << Q_FUNC_INFO << ": going for slotQRZTextChanged";
+         //qDebug() << Q_FUNC_INFO << ": going for slotQRZTextChanged";
         text = lastQrz;
         slotQRZTextChanged();
     }
@@ -1085,10 +1106,10 @@ bool MainQSOEntryWidget::getDarkMode()
 /*
 void MainQSOEntryWidget::keyPressEvent( QKeyEvent *event)
 {
-    //qDebug() << Q_FUNC_INFO;
+     //qDebug() << Q_FUNC_INFO;
     if(event->key()==Qt::Key_Enter)
     {
-        //qDebug() << Q_FUNC_INFO << " TAB...";
+         //qDebug() << Q_FUNC_INFO << " TAB...";
     }
 }
 */
@@ -1096,25 +1117,26 @@ void MainQSOEntryWidget::keyPressEvent( QKeyEvent *event)
 bool MainQSOEntryWidget::eventFilter(QObject *object, QEvent *event)
 {
     logEvent (Q_FUNC_INFO, "Start", Debug);
+    Q_UNUSED(object);
     if (!(event->type() == QEvent::Paint ))
     {
-        //qDebug() << Q_FUNC_INFO << ": " << QString::number(event->type ());
+         //qDebug() << Q_FUNC_INFO << ": " << QString::number(event->type ());
     }
 
     if ((event->type() == QEvent::KeyPress) || (event->type() == QEvent::ShortcutOverride)) {
-        //qDebug() << Q_FUNC_INFO << "KEY PRESSED";
+         //qDebug() << Q_FUNC_INFO << "KEY PRESSED";
         QKeyEvent *ke = static_cast<QKeyEvent *>(event);
         if (ke->key() == Qt::Key_Tab) {
-            //qDebug() << Q_FUNC_INFO << "KEY PRESSED TAB";
+             //qDebug() << Q_FUNC_INFO << "KEY PRESSED TAB";
             if ((realtimeCheckBox->isChecked ()) && (qrzLineEdit->hasFocus ()))
             {
-                //qDebug() << Q_FUNC_INFO << "KEY PRESSED TAB AND REAL TIME CHECKED";
-                 //qDebug() << Q_FUNC_INFO << "emitting to hand over to QSO TAB-1";
+                 //qDebug() << Q_FUNC_INFO << "KEY PRESSED TAB AND REAL TIME CHECKED";
+                  //qDebug() << Q_FUNC_INFO << "emitting to hand over to QSO TAB-1";
                 emit handOverFocusSignal();
             }
             else if((!realtimeCheckBox->isChecked ()) && timeEdit->hasFocus () && (timeEdit->currentSection() == QTimeEdit::SecondSection))
             {
-                //qDebug() << Q_FUNC_INFO << "emitting to hand over to QSO TAB-2";
+                 //qDebug() << Q_FUNC_INFO << "emitting to hand over to QSO TAB-2";
                 emit handOverFocusSignal();
             }
             // special tab handling here
@@ -1135,16 +1157,16 @@ void MainQSOEntryWidget::setFocusToOK()
 
 void MainQSOEntryWidget::slotCaptureDebugLogs(const QString &_func, const QString &_msg, DebugLogLevel _level)
 {
-    //qDebug() << Q_FUNC_INFO << _func << "/" << _msg << "/" << QString::number(_level);
+     //qDebug() << Q_FUNC_INFO << _func << "/" << _msg << "/" << QString::number(_level);
     logEvent(_func, _msg, _level);
 }
 
 void MainQSOEntryWidget::logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level)
 {
-    //qDebug() << Q_FUNC_INFO;
+     //qDebug() << Q_FUNC_INFO;
     if (logLevel<=_level)
     {
-        //qDebug() << Q_FUNC_INFO << "Emitting...";
+         //qDebug() << Q_FUNC_INFO << "Emitting...";
         emit debugLog (_func, _msg, _level);
     }
 }
