@@ -39,8 +39,8 @@ class MainQSOEntryWidget : public QWidget
 public:
     explicit MainQSOEntryWidget(DataProxy_SQLite *dp, QWidget *parent = nullptr);
     ~MainQSOEntryWidget();
-    void setBands(const QStringList _bands);
-    void setModes(const QStringList _modes);
+    void setBands(const QStringList &_bands);
+    void setModes(const QStringList &_modes);
 
     bool setBand(const QString &_band);
     bool setFreq(const double _f, bool isRX = false);
@@ -105,6 +105,7 @@ private slots:
     void slotModeComboBoxChanged(const QString &_m);
     void slotOKButtonClicked();
     void slotClearButtonClicked();
+    void slotQRZButtonClicked();
     //void slotRealtimeButtonClicked();
     void slotCheckBoxClicked();
     //void slotRealTimeCheckBoxChanged();
@@ -131,7 +132,7 @@ private:
     QComboBox *bandComboBox, *modeComboBox;
     QDateEdit *dateEdit;
     QTimeEdit *timeEdit;
-    QPushButton *OKButton, *clearButton;
+    QPushButton *OKButton, *clearButton, *QRZButton;
     QCheckBox *realtimeCheckBox, *manualModeCheckBox;
     //QPushButton *realtimeButton;
     //DebugLogLevel logLevel;
@@ -159,7 +160,7 @@ private:
     QString lastQrz;
     double freqTX, freqRX, bottomBandLimit, upperBandLimit;
     DebugLogLevel logLevel;
-    //HamLibClass *hamlib;
+    bool modifyingBands;
 };
 
 #endif // MAINQSOENTRYWIDGET_H
