@@ -30,6 +30,7 @@
 #include <QStringList>
 #include <QListWidget>
 #include "../dataproxy_sqlite.h"
+#include "../utilities.h"
 
 
 class SetupPageBandMode : public QWidget
@@ -40,11 +41,12 @@ public:
     ~SetupPageBandMode();
 
 
-    QString getBands(); // 10m, 12m, 15m
-    QString getModes(); //ssb, CW
+    QStringList getBands(); // 10m, 12m, 15m
+    QStringList getModes(); //ssb, CW
 
     void setActiveBands(QStringList q);
     void setActiveModes(QStringList q);
+    void saveSettings();
 
 signals:
 
@@ -57,6 +59,7 @@ private:
     QListWidget *bandsListWidget, *modesListWidget;
 
     DataProxy_SQLite *dataProxy;
+    Utilities *util;
 
 };
 
