@@ -30,6 +30,7 @@
 #include <QStringList>
 #include <QListWidget>
 #include "../dataproxy_sqlite.h"
+#include "../utilities.h"
 
 
 class SetupPageLogView : public QWidget
@@ -38,11 +39,10 @@ class SetupPageLogView : public QWidget
 public:
     SetupPageLogView(DataProxy_SQLite *dp, QWidget *parent=nullptr);
     ~SetupPageLogView();
-
-    QString getFields();
-
-    void setActiveFields(QStringList _q);
-
+    void init();
+    //QString getFields();
+    void saveSettings();
+    void loadSettings();
 
 signals:
 
@@ -50,6 +50,8 @@ public slots:
 
 private:
     void addFields (QStringList _b); // read the available fields from the DB
+    QStringList getActiveFields();
+    void setActiveFields(QStringList _q);
 
     QListWidget *fieldsListWidget;
 
