@@ -40,6 +40,7 @@ class SetupPageUserDataPage : public QWidget {
 public:
     SetupPageUserDataPage(DataProxy_SQLite *dp, QWidget *parent=nullptr);
     ~SetupPageUserDataPage();
+    void setPrefixes();
 
     QString getMainCallsign();
     QString getOperators();
@@ -86,11 +87,11 @@ public:
     QString getAntenna3();
     QStringList getRigs();
     QStringList getAntennas();
-    QString getPower();
+    double getPower();
 
     bool setRigs(const QStringList _aux);
     bool setAntennas(const QStringList _aux);
-    bool setPower(const QString &_aux);
+    bool setPower(const float _aux);
     bool setRig1 (const QString &_aux);
     bool setRig2 (const QString &_aux);
     bool setRig3 (const QString &_aux);
@@ -99,6 +100,8 @@ public:
     bool setAntenna2 (const QString &_aux);
     bool setAntenna3 (const QString &_aux);
     void setStationFocus();
+    void saveSettings();
+    void loadSettings();
 
 signals:
     void mainCallsignSignal (const QString &_p);
@@ -158,6 +161,7 @@ private:
 
     bool operatorsOK;
     bool mainCallOK;
+    bool slotQRZRunning;
     Utilities *util;
 
 };
