@@ -30,7 +30,7 @@
  StartWizard::StartWizard(const QString &_klogDir, const QString &_softVersion, QWidget *parent)
      : QWizard(parent)
  {
-        //qDebug() << "StartWizard::StartWizard: v=" << _softVersion << QT_ENDL;
+        //qDebug() << "StartWizard::StartWizard: v=" << _softVersion;
     //licAcepted = false;
     version = _softVersion;
     klogDir = _klogDir;
@@ -67,7 +67,7 @@
 
     setWindowTitle(tr("KLog - The free hamradio logging program"));
 
-       //qDebug() << "StartWizard::StartWizard: - END" << QT_ENDL;
+       //qDebug() << "StartWizard::StartWizard: - END";
 
  }
 
@@ -78,14 +78,14 @@
 
 /*void StartWizard::slotUpdateDownloadProgress(qint64 received, qint64 total)
 {
-        //qDebug() << "StartWizard::slotUpdateDownloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
+        //qDebug() << "StartWizard::slotUpdateDownloadProgress: " << QString::number(received) << "/" << QString::number(total);
      ctyPage->updateProgress(received, total);
 }
 */
 /*
  void StartWizard::slotDownloadFinished()
 {
-        //qDebug() << "StartWizard::slotDownloadFinished" << QT_ENDL;
+        //qDebug() << "StartWizard::slotDownloadFinished";
      //close();
 }
 */
@@ -101,7 +101,7 @@
 
  void StartWizard::slotButtonFinishedClicked()
  {
-        //qDebug() << "StartWizard::slotButtonFinishedClicked " << QT_ENDL;
+        //qDebug() << "StartWizard::slotButtonFinishedClicked ";
     setResult(2);
  }
 
@@ -109,7 +109,7 @@
 
  bool StartWizard::doTheDownload()
  {
-        //qDebug() << "StartWizard::doTheDownload" << QT_ENDL;
+        //qDebug() << "StartWizard::doTheDownload";
     int downloading = 1;
     int i = 0;
     int ret;
@@ -132,7 +132,7 @@
 
  void StartWizard::slotValueReturnedFromDownload(int value)
  {
-        //qDebug() << "StartWizard::slotValueReturnedFromDownload: " << QString::number(value) << QT_ENDL;
+        //qDebug() << "StartWizard::slotValueReturnedFromDownload: " << QString::number(value);
      downloadValueResult = value;
      //close();
  }
@@ -966,15 +966,14 @@ CTYPage::CTYPage(const QString &_klogDir, const QString &_version, QWidget *pare
 
 void CTYPage::slotUpdateDownloadProgress(qint64 received, qint64 total)
 {
-       //qDebug() << "CTYPage::slotUpdateDownloadProgress: " << QString::number(received) << "/" << QString::number(total) << QT_ENDL;
-
+       //qDebug() << "CTYPage::slotUpdateDownloadProgress: " << QString::number(received) << "/" << QString::number(total);
+    Q_UNUSED(total);
     progressBar->setValue(received);
-
 }
 
 void CTYPage::slotDownloadButtonClicked()
 {
-        //qDebug() << "CTYPage::slotDownloadButtonClicked" << QT_ENDL;
+        //qDebug() << "CTYPage::slotDownloadButtonClicked";
      progressBar->setEnabled(true);
      progressBar->reset();
      progressBar->setRange(0, 0);
@@ -983,7 +982,7 @@ void CTYPage::slotDownloadButtonClicked()
 }
 void CTYPage::slotIgnoreDownloadButtonClicked()
 {
-    //qDebug() << "CTYPage::slotIgnoreDownloadButtonClicked" << QT_ENDL;
+    //qDebug() << "CTYPage::slotIgnoreDownloadButtonClicked";
     //ignoreDownloadButton->setChecked(true);
     slotStopProgressBar();
     hiddenCheckBox->setChecked(true);
@@ -995,7 +994,7 @@ void CTYPage::slotIgnoreDownloadButtonClicked()
 
 void CTYPage::slotDownloadFinished(const int ret)
 {
-    //qDebug() << "CTYPage::slotDownloadFinished: " << QString::number(ret) << QT_ENDL;
+    //qDebug() << "CTYPage::slotDownloadFinished: " << QString::number(ret);
     slotStopProgressBar();
      if (ret == QNetworkReply::NoError) // No error
      {
@@ -1003,15 +1002,15 @@ void CTYPage::slotDownloadFinished(const int ret)
         progressBar->setEnabled(false);
         //progressBar->setValue(progressBar->maximum());
         //hiddenCheckBox->setChecked(true);
-        //qDebug() << "CTYPage::slotDownloadFinished: (no error): " << QString::number(ret) << QT_ENDL;
+        //qDebug() << "CTYPage::slotDownloadFinished: (no error): " << QString::number(ret);
      }
      else if (ret == -1) // File could not be created!
      {
-           //qDebug() << "CTYPage::slotDownloadFinished: (file could not be created): " << QString::number(ret) << QT_ENDL;
+           //qDebug() << "CTYPage::slotDownloadFinished: (file could not be created): " << QString::number(ret);
      }
      else
      {
-       //qDebug() << "CTYPage::slotDownloadFinished: (another result): " << QString::number(ret) << QT_ENDL;
+       //qDebug() << "CTYPage::slotDownloadFinished: (another result): " << QString::number(ret);
      }
 
 
@@ -1019,7 +1018,7 @@ void CTYPage::slotDownloadFinished(const int ret)
 
 void CTYPage::slotDownloadError(const int ret)
 {
-    //qDebug() << "CTYPage::slotDownloadError: " << QString::number(ret) << QT_ENDL;
+    //qDebug() << "CTYPage::slotDownloadError: " << QString::number(ret);
     int errorCode = ret;
     int i;
     slotStopProgressBar();
@@ -1057,7 +1056,7 @@ void CTYPage::slotDownloadError(const int ret)
 
 void CTYPage::slotStopProgressBar()
 {
-    //qDebug() << "CTYPage::slotStopProgressBar" << QT_ENDL;
+    //qDebug() << "CTYPage::slotStopProgressBar";
     progressBar->reset();
     progressBar->setRange(0,1);
     progressBar->setValue(1);
