@@ -30,7 +30,7 @@
 Utilities::Utilities(const QString &_parentName)
 {
     parentName = _parentName;
-    //qDebug() << "Utilities::Utilities"  ;
+    //qDebug() << Q_FUNC_INFO << " (" << _parentName << ")";
     init();
 }
 
@@ -40,11 +40,12 @@ Utilities::~Utilities()
 
 void Utilities::init()
 {
+    //qDebug() << Q_FUNC_INFO << " - Start";
     validateCalls = false;
     softwareVersion = "0.0";
     longPrefixes.clear();
     specialCalls.clear();
-    darkMode = false;
+    //darkMode = false;
     logLevel = None;
     setARRLSect();
     setContinent();
@@ -53,7 +54,7 @@ void Utilities::init()
     logLevels << "None" << "Info" << "Debug" << "Devel";
     setLogColumnNames();
 
-    //callValidation = true;
+    //qDebug() << Q_FUNC_INFO << " - END";
 }
 
 void Utilities::setLogLevel(DebugLogLevel _l)
@@ -617,6 +618,7 @@ bool Utilities::isValidSimpleCall(const QString &_c)
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << QString(" - 000 - %1").arg(_c);
     if ((_c.contains('/')) || (_c.contains('\\')))
     {
+        //qDebug() << Q_FUNC_INFO << " -001";
         return false;
     }
     int length = _c.length();
@@ -695,15 +697,14 @@ bool Utilities::isValidSimpleCall(const QString &_c)
         }
     }
     //qDebug() << Q_FUNC_INFO << "END";
-    return true;
-
     logEvent (QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName), QString("END - TRUE"), Debug);
+    return true;
 }
 
 bool Utilities::isAValidOperatingSuffix (const QString &_c)
 {
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << _c;
-    QStringList validSuffixes = {"A", "P", "Q", "AM", "M", "MM", "LH", "R", "J", "FF", "QRP", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0"};
+    QStringList validSuffixes = {"A", "P", "Q", "AM", "M", "MM", "LH", "R", "J", "FF", "QRP", "QRPP", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0"};
     return validSuffixes.contains (_c);
 }
 
@@ -730,7 +731,6 @@ void Utilities::setLongPrefixes (const QStringList &_p)
 {
     //qDebug() << Q_FUNC_INFO << ": Start count: " << QString::number(_p.count());
     longPrefixes.clear();
-    //longPrefixes = _p;
     longPrefixes.append(_p);
     //qDebug() << Q_FUNC_INFO << ": count: " << QString::number(longPrefixes.count());
 }
@@ -914,20 +914,24 @@ QString Utilities::getMainCallFromComplexCall(const QString &_complexCall)
     return call;
 }
 
-bool Utilities::isValidCall(const QString &_c)
+bool Utilities::isValidCall(const QString &_c, bool _force)
 {// https://life.itu.int/radioclub/rr/art19.pdf
     //logEvent (QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName), QString("Start = %1").arg(_c), Debug);
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << "Start: " << _c;
     //qDebug() << Q_FUNC_INFO << ": " << _c;
     // Prefixes are at least 2 chars
-    if (!validateCalls)
+
+    if ((!validateCalls) && (!_force))
     {
         //qDebug() << Q_FUNC_INFO << "001 - Not validating calls: " << _c;
         //logEvent (QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName), QString("END - 001 - true"), Debug);
         return true;
     }
+
+    //qDebug() << Q_FUNC_INFO << " - Long prefixes: " << QString::number(longPrefixes.count());
     if (longPrefixes.count()<100)
     {
+        //qDebug() << Q_FUNC_INFO << "Long prefixes < 100 " << _c;
         return false;
     }
     QString call = _c;
@@ -957,6 +961,7 @@ bool Utilities::isValidCall(const QString &_c)
     if (call.count('/')>2)
     {
         //logEvent (QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName), QString("END - 015 - false"), Debug);
+        //qDebug() << Q_FUNC_INFO << " -005.5";
         return false;
     }
     //qDebug() << Q_FUNC_INFO << " -006";
@@ -1032,7 +1037,7 @@ QString Utilities::getPrefixFromCall(const QString &_c, bool withAreaNumber)
             //qDebug() << Q_FUNC_INFO << " - Known CALL found!";
             return _c;
         }
-         //qDebug() << Q_FUNC_INFO << " - Call not found!" ;
+        //qDebug() << Q_FUNC_INFO << " - Call not found!" ;
     }
 
     //qDebug() << Q_FUNC_INFO << " - 010";
@@ -1262,35 +1267,39 @@ bool Utilities::isValidGrid(const QString &_b)
 
 bool Utilities::isValidVUCCGrids(const QString &_b)
 {
+    //qDebug() << Q_FUNC_INFO << ": " << _b;
+    if(_b.endsWith (','))
+        return false;
     //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": " << _b;
     QStringList tmp;
 
     //QString a = _b;
     tmp.clear ();
     tmp << _b.split (',', QT_SKIP);
-
-    if ((tmp.length ()!=2) && (tmp.length ()!=4))
+   //qDebug() << Q_FUNC_INFO << ": 10";
+    if ((tmp.length () !=2) && (tmp.length () !=4) )
     {
-        //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": NON VALID LENGTH";
+        //qDebug() << Q_FUNC_INFO << ": 11 - not valid lenght";
         return false;
     }
+    //qDebug() << Q_FUNC_INFO << ": 20";
 
-    //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": tmp: " << tmp;
     QString aux;
     foreach (aux, tmp) {
         aux = aux.trimmed ();
 
-        if ((!isValidGrid (aux)) || (aux.length ()!=4))
+        //if ((!isValidGrid (aux)) || (aux.length ()!=4))
+        if (!isValidGrid (aux))
         {
-            //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": NON VALID";
+           //qDebug() << Q_FUNC_INFO << ": 30 - non valid: " << aux;
             return false;
         }
         else
         {
-            //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": VALID: " << aux;
+           //qDebug() << Q_FUNC_INFO << ": 31 - valid";
         }
     }
-    //qDebug() << QString("%1-%2").arg(Q_FUNC_INFO).arg(parentName) << ": VALID-END";
+   //qDebug() << Q_FUNC_INFO << ": 100 - VALID END";
     return true;
 }
 
@@ -1314,17 +1323,10 @@ bool Utilities::isValidName(const QString &_b)
     return (_b.length()>0);
 }
 
-bool Utilities::isDBFileExisting()
+bool Utilities::fileExists(const QString &_fileName)
 {
-    //qDebug() << "Utilities::isDBFileExisting: " << getKLogDBFile() ;
-    return (QFile::exists(getKLogDBFile()));
-}
-
-bool Utilities::isDBFileExisting(const QString &_file)
-{
-         //qDebug() << "Utilities::isDBFileExisting2: " << _file ;
-
-    return (QFile::exists(_file));
+    //qDebug() << Q_FUNC_INFO << _file ;
+    return (QFile::exists(_fileName));
 }
 
 bool Utilities::isValidADIFField(const QString &_b)
@@ -1507,8 +1509,7 @@ QStringList Utilities::getValidADIFFieldAndData(const QString &_b)
         return result;
     }
      //qDebug() << "Utilities::getValidADIFFieldAndData: -90: f: " << field ;
-      //qDebug() << "Utilities::getValidADIFFieldAndData: -90: d: " << data<< endl;
-    //field = field.section(':', 0, 0);
+      //qDebug() << "Utilities::getValidADIFFieldAndData: -90: d: " << data;ield = field.section(':', 0, 0);
     result.clear();
     result << field.section(':', 0, 0) << data;
      //qDebug() << "Utilities::checkADIFValidFormat: Return true: " << result.at(0) << "/" << result.at(1) ;
@@ -1745,15 +1746,15 @@ QString Utilities::getClearSQLi(QString _s)
     return _s.remove ('\'');
 }
 
-void Utilities::setDarkMode(const QString &_dm)
-{
-    darkMode = trueOrFalse(_dm);
-}
+//void Utilities::setDarkMode(const QString &_dm)
+//{
+//    darkMode = trueOrFalse(_dm);
+//}
 
-bool Utilities::isDarkMode()
-{
-    return darkMode;
-}
+//bool Utilities::isDarkMode()
+//{
+//    return darkMode;
+//}
 
 void Utilities::setLogColumnNames()
 {
@@ -2189,6 +2190,16 @@ bool Utilities::isValidContinent(const QString &_s)
     return (continent.contains (_s.toUpper ()));
 }
 
+bool Utilities::isValidPropMode(const QString &_s)
+{
+    QStringList propModes;
+    propModes.clear ();
+    propModes << "AS" << "AUE" << "AUR" << "BS" << "ECH" << "EME" << "ES"
+                << "F2" << "FAI" << "GWAVE" << "INTERNET" << "ION" << "IRL"
+                << "LOS" << "MS" << "RPT" << "RS" << "SAT" << "TEP" << "TR";
+    return propModes.contains (_s.toUpper ());
+}
+
 bool Utilities::isValidDistance(const double _d)
 {
     return (_d>=0);
@@ -2199,6 +2210,11 @@ bool Utilities::isValidSponsor(const QString &_s)
     return (sponsorsList.contains (_s.toUpper ()));
 }
 
+ void Utilities::openQrzcom(const QString _call)
+ {
+     QString url = "https://www.qrz.com/lookup/" + _call;
+     QDesktopServices::openUrl(QUrl(url));
+ }
 QString Utilities::debugLevelToString(DebugLogLevel _l)
 {
     switch (_l) {
