@@ -50,8 +50,8 @@ class Utilities : public QObject {
 public:
     Utilities(const QString &_parentName);
     ~Utilities();
-    void setDarkMode(const QString &_dm);
-    bool isDarkMode();
+    //void setDarkMode(const QString &_dm);
+    //bool isDarkMode();
     void setCallValidation(const bool _b);
     void setLongPrefixes (const QStringList &_p);
     void setSpecialCalls (const QStringList &_p);
@@ -71,8 +71,8 @@ public:
     bool QStringToBool(const QString &_s);
 
     //QString getKLogDatabaseFile(const QString &_file);
-    bool isDBFileExisting();
-    bool isDBFileExisting(const QString &_file);
+    bool fileExists(const QString &_fileName);
+
     QString getTQSLsFileName();
     QString getTQSLsPath();   // Depending on the OS where are usually installed the executables
     QString getHomeDir();
@@ -98,7 +98,7 @@ public:
     // Validations
     bool isValidDate(const QDate _d);
     bool isValidDateTime(const QString &_d);
-    bool isValidCall(const QString &_c);
+    bool isValidCall(const QString &_c, bool _force=false);
 
     bool isSameFreq(const double fr1, const double fr2);
     bool isValidBandId(const int _b);
@@ -122,6 +122,7 @@ public:
     bool isValidAntPath(const QString &_s);
     bool isValidARRLSect(const QString &_s);
     bool isValidContinent(const QString &_s);
+    bool isValidPropMode(const QString &_s);
     QStringList getValidADIFFieldAndData(const QString &_b);
 
     QString getMainCallFromComplexCall(const QString &_complexCall); // F from F/EA4K/p, EA4K from EA4K/p or EA4K from EA4K
@@ -167,6 +168,7 @@ public:
     bool isValidLogLevel(const QString &_s);
     QStringList getDebugLevels();
     void setLogLevel(DebugLogLevel _l);
+    void openQrzcom(const QString _call);
     //QPalette getPalete(bool _ok);
 signals:
     void debugLog (QString _func, QString _msg, DebugLogLevel _level);
@@ -189,7 +191,7 @@ private:
     void setSponsorsList();
     QString getCheckedComplexCall(const QString &_c);
     void logEvent(const QString &_func, const QString &_msg, DebugLogLevel _level);
-    bool darkMode;
+    //bool darkMode;
     QString dbPath;
     QString softwareVersion;
     QString parentName;     // The class that instanciated this object.
